@@ -19,42 +19,44 @@
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+
 #include "connectioneditor.h"
-#include "ui_connectioneditor.h"
 #include "connectiondetaileditor.h"
 #include "editoridentitymodel.h"
 #include "editorproxymodel.h"
 #include "networkmodel.h"
 #include "mobileconnectionwizard.h"
 #include "uiutils.h"
+#include "ui_connectioneditor.h"
 #include "vpnuiplugin.h"
 #include <networkmodelitem.h>
 
+#include <QFileDialog>
+#include <QStandardPaths>
+#include <QUrl>
+#include <QAction>
+#include <QIcon>
+
+#include <KAcceleratorManager>
 #include <KActionCollection>
-#include <KLocale>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KFilterProxySearchLine>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KService>
 #include <KServiceTypeTrader>
-#include <KStandardAction>
-#include <KAction>
-#include <KXMLGUIFactory>
-#include <KMenu>
-#include <KAcceleratorManager>
-#include <KConfig>
-#include <KConfigGroup>
-#include <KWallet/Wallet>
-#include <KStandardDirs>
-#include <KFileDialog>
 #include <KShell>
-#include <KFilterProxySearchLine>
+#include <KStandardAction>
+#include <KXMLGUIFactory>
+#include <KWallet/Wallet>
 
-#include <NetworkManagerQt/Settings>
-#include <NetworkManagerQt/Connection>
 #include <NetworkManagerQt/ActiveConnection>
+#include <NetworkManagerQt/Connection>
+#include <NetworkManagerQt/Ipv4Setting>
+#include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/VpnSetting>
 
-using namespace NetworkManager;
-
 ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
     : KXmlGuiWindow(parent, flags)
     , m_editor(new Ui::ConnectionEditor)
@@ -73,7 +75,7 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
     m_editor->messageWidget->setCloseButtonVisible(false);
     m_editor->messageWidget->setWordWrap(true);
 
-    m_editor->ktreewidgetsearchline->lineEdit()->setClickMessage(i18n("Type here to search connections..."));
+    m_editor->ktreewidgetsearchline->lineEdit()->setPlaceholderText(i18n("Type here to search connections..."));
 
     initializeConnections();
     initializeMenu();
@@ -89,7 +91,7 @@ ConnectionEditor::ConnectionEditor(QWidget* parent, Qt::WindowFlags flags)
     connect(NetworkManager::settingsNotifier(), SIGNAL(connectionAdded(QString)),
             SLOT(connectionAdded(QString)));
 
-    KConfig config("kde-nm-connection-editor");
+    KConfig config("kde5-nm-connection-editor");
     KConfigGroup generalGroup = config.group("General");
 
     if (generalGroup.isValid()) {
@@ -108,7 +110,7 @@ ConnectionEditor::~ConnectionEditor()
 
 void ConnectionEditor::initializeMenu()
 {
-    m_menu = new KActionMenu(KIcon("list-add"), i18n("Add"), this);
+    m_menu = new KActionMenu(QIcon::fromTheme("list-add"), i18n("Add"), this);
     m_menu->menu()->setSeparatorsCollapsible(false);
     m_menu->setDelayed(false);
 
@@ -159,6 +161,11 @@ void ConnectionEditor::initializeMenu()
     action = new QAction(i18n("VLAN"), this);
     action->setData(NetworkManager::ConnectionSettings::Vlan);
     m_menu->addAction(action);
+#if NM_CHECK_VERSION(0, 9, 10)
+    action = new QAction(i18n("Team"), this);
+    action->setData(NetworkManager::ConnectionSettings::Team);
+    m_menu->addAction(action);
+#endif
 
     action = m_menu->addSeparator();
     action->setText(i18n("VPN"));
@@ -175,32 +182,22 @@ void ConnectionEditor::initializeMenu()
 
     actionCollection()->addAction("add_connection", m_menu);
 
-    KAction * kAction = new KAction(KIcon("network-connect"), i18n("Connect"), this);
-    kAction->setEnabled(false);
-    connect(kAction, SIGNAL(triggered()), this, SLOT(connectConnection()));
-    actionCollection()->addAction("connect_connection", kAction);
-
-    kAction = new KAction(KIcon("network-disconnect"), i18n("Disconnect"), this);
-    kAction->setEnabled(false);
-    connect(kAction, SIGNAL(triggered()), this, SLOT(disconnectConnection()));
-    actionCollection()->addAction("disconnect_connection", kAction);
-
-    kAction = new KAction(KIcon("configure"), i18n("Edit..."), this);
+    QAction * kAction = new QAction(QIcon::fromTheme("configure"), i18n("Edit..."), this);
     kAction->setEnabled(false);
     connect(kAction, SIGNAL(triggered()), SLOT(editConnection()));
     actionCollection()->addAction("edit_connection", kAction);
 
-    kAction = new KAction(KIcon("edit-delete"), i18n("Delete"), this);
+    kAction = new QAction(QIcon::fromTheme("edit-delete"), i18n("Delete"), this);
     kAction->setEnabled(false);
-    kAction->setShortcut(Qt::Key_Delete);
+    kAction->setShortcut(QKeySequence::Delete);
     connect(kAction, SIGNAL(triggered()), SLOT(removeConnection()));
     actionCollection()->addAction("delete_connection", kAction);
 
-    kAction = new KAction(KIcon("document-import"), i18n("Import VPN..."), this);
+    kAction = new QAction(QIcon::fromTheme("document-import"), i18n("Import VPN..."), this);
     actionCollection()->addAction("import_vpn", kAction);
     connect(kAction, SIGNAL(triggered()), SLOT(importVpn()));
 
-    kAction = new KAction(KIcon("document-export"), i18n("Export VPN..."), this);
+    kAction = new QAction(QIcon::fromTheme("document-export"), i18n("Export VPN..."), this);
     actionCollection()->addAction("export_vpn", kAction);
     kAction->setEnabled(false);
     connect(kAction, SIGNAL(triggered()), SLOT(exportVpn()));
@@ -217,41 +214,95 @@ void ConnectionEditor::initializeMenu()
 
 void ConnectionEditor::addConnection(QAction* action)
 {
-    qDebug() << "ADDING new connection" << action->data().toUInt();
+    NetworkManager::ConnectionSettings::Ptr connectionSettings;
+    NetworkManager::ConnectionSettings::ConnectionType type = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(action->data().toUInt());
     const QString vpnType = action->property("type").toString();
-    qDebug() << "VPN type:" << vpnType;
 
-    ConnectionSettings::ConnectionType type = static_cast<ConnectionSettings::ConnectionType>(action->data().toUInt());
+    qDebug() << "Adding new connection of type " << type;
+    if (type == NetworkManager::ConnectionSettings::Vpn) {
+        qDebug() << "VPN type: " << vpnType;
+    }
+
 
     if (type == NetworkManager::ConnectionSettings::Gsm) { // launch the mobile broadband wizard, both gsm/cdma
 #if WITH_MODEMMANAGER_SUPPORT
         QWeakPointer<MobileConnectionWizard> wizard = new MobileConnectionWizard(NetworkManager::ConnectionSettings::Unknown, this);
         if (wizard.data()->exec() == QDialog::Accepted && wizard.data()->getError() == MobileProviders::Success) {
             qDebug() << "Mobile broadband wizard finished:" << wizard.data()->type() << wizard.data()->args();
-            QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(wizard.data()->type(), wizard.data()->args(), this);
-            editor->exec();
 
-            if (editor) {
-                editor->deleteLater();
+            if (wizard.data()->args().count() == 2) {
+                QVariantMap tmp = qdbus_cast<QVariantMap>(wizard.data()->args().value(1));
+
+#if 0 // network IDs are not used yet and seem to break the setting
+        if (args.count() == 3) { // gsm specific
+            QStringList networkIds = args.value(1).toStringList();
+            if (!networkIds.isEmpty())
+                tmp.insert("network-id", networkIds.first());
+        }
+#endif
+                connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(wizard.data()->type()));
+                connectionSettings->setId(wizard.data()->args().value(0).toString());
+                if (wizard.data()->type() == NetworkManager::ConnectionSettings::Gsm) {
+                    connectionSettings->setting(NetworkManager::Setting::Gsm)->fromMap(tmp);
+                } else if (wizard.data()->type() == NetworkManager::ConnectionSettings::Cdma) {
+                    connectionSettings->setting(NetworkManager::Setting::Cdma)->fromMap(tmp);
+                } else {
+                    qWarning() << Q_FUNC_INFO << "Unhandled setting type";
+                }
+            } else {
+                qWarning() << Q_FUNC_INFO << "Unexpected number of args to parse";
             }
         }
+
         if (wizard) {
             wizard.data()->deleteLater();
         }
+
 #endif
     } else {
-        bool shared = false;
-        if (type == ConnectionSettings::Wired || type == ConnectionSettings::Wireless) {
-            shared = action->property("shared").toBool();
-        }
+        connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(type));
 
-        QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(type, this, vpnType, shared);
-        editor->exec();
+        if (type == NetworkManager::ConnectionSettings::Wired || type == NetworkManager::ConnectionSettings::Wireless) {
+            bool shared = action->property("shared").toBool();
+            if (shared) {
+                if (type == NetworkManager::ConnectionSettings::Wireless) {
+                    NetworkManager::WirelessSetting::Ptr wifiSetting = connectionSettings->setting(NetworkManager::Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
+                    wifiSetting->setMode(NetworkManager::WirelessSetting::Adhoc);
+                    wifiSetting->setSsid(i18n("my_shared_connection").toUtf8());
 
-        if (editor) {
-            editor->deleteLater();
+                    foreach (const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
+                        if (device->type() == NetworkManager::Device::Wifi) {
+                            NetworkManager::WirelessDevice::Ptr wifiDev = device.objectCast<NetworkManager::WirelessDevice>();
+                            if (wifiDev) {
+                                if (wifiDev->wirelessCapabilities().testFlag(NetworkManager::WirelessDevice::ApCap)) {
+                                    wifiSetting->setMode(NetworkManager::WirelessSetting::Ap);
+                                    wifiSetting->setMacAddress(NetworkManager::Utils::macAddressFromString(wifiDev->hardwareAddress()));
+                                }
+                            }
+                        }
+                    }
+                }
+
+                NetworkManager::Ipv4Setting::Ptr ipv4Setting = connectionSettings->setting(NetworkManager::Setting::Ipv4).dynamicCast<NetworkManager::Ipv4Setting>();
+                ipv4Setting->setMethod(NetworkManager::Ipv4Setting::Shared);
+                connectionSettings->setAutoconnect(false);
+            }
         }
     }
+
+    // Generate new UUID
+    connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
+
+    QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(connectionSettings, true);
+
+    if (editor->exec() == QDialog::Accepted) {
+        qDebug() << editor->setting();
+        m_handler->addConnection(editor->setting());
+    }
+
+    if (editor) {
+        editor->deleteLater();
+    }
 }
 
 void ConnectionEditor::connectionAdded(const QString& connection)
@@ -286,21 +337,6 @@ void ConnectionEditor::connectConnection()
     m_handler->activateConnection(connectionPath, devicePath, specificPath);
 }
 
-void ConnectionEditor::dataChanged(const QModelIndex& topLeft, const QModelIndex& bottomRight)
-{
-    QModelIndex currentIndex = m_editor->connectionsWidget->currentIndex();
-    if (currentIndex.isValid()) {
-        for (int i = topLeft.row(); i <= bottomRight.row(); i++) {
-            QModelIndex index = m_editor->connectionsWidget->model()->index(i, 0);
-            if (index.isValid() && index == currentIndex) {
-                // Re-check enabled/disabled actions
-                slotItemClicked(currentIndex);
-                break;
-            }
-        }
-    }
-}
-
 void ConnectionEditor::disconnectConnection()
 {
     const QModelIndex currentIndex = m_editor->connectionsWidget->currentIndex();
@@ -328,13 +364,14 @@ void ConnectionEditor::editConnection()
 void ConnectionEditor::initializeConnections()
 {
     EditorIdentityModel * model = new EditorIdentityModel(this);
+
     EditorProxyModel * filterModel = new EditorProxyModel(this);
     filterModel->setSourceModel(model);
-    connect(filterModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),SLOT(dataChanged(QModelIndex,QModelIndex)));
 
     m_editor->connectionsWidget->setModel(filterModel);
     m_editor->ktreewidgetsearchline->setProxy(filterModel);
-    m_editor->connectionsWidget->header()->setResizeMode(0, QHeaderView::Stretch);
+
+    m_editor->connectionsWidget->header()->setSectionResizeMode(0, QHeaderView::Stretch);
 }
 
 void ConnectionEditor::removeConnection()
@@ -345,7 +382,7 @@ void ConnectionEditor::removeConnection()
         return;
     }
 
-    Connection::Ptr connection = NetworkManager::findConnectionByUuid(currentIndex.data(NetworkModel::UuidRole).toString());
+    NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(currentIndex.data(NetworkModel::UuidRole).toString());
 
     if (!connection) {
         return;
@@ -357,10 +394,10 @@ void ConnectionEditor::removeConnection()
         foreach (const NetworkManager::Connection::Ptr &con, NetworkManager::listConnections()) {
             NetworkManager::ConnectionSettings::Ptr settings = con->settings();
             if (settings->master() == connection->uuid()) {
-                con->remove();
+                m_handler->removeConnection(con->path());
             }
         }
-        connection->remove();
+        m_handler->removeConnection(connection->path());
     }
 }
 
@@ -373,9 +410,9 @@ void ConnectionEditor::slotContextMenuRequested(const QPoint&)
     const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
 
     if (isAvailable && !isActive) {
-        menu->addAction(actionCollection()->action("connect_connection"));
+        menu->addAction(QIcon::fromTheme("user-online"), i18n("Connect"), this, SLOT(connectConnection()));
     } else if (isAvailable && isActive) {
-        menu->addAction(actionCollection()->action("disconnect_connection"));
+        menu->addAction(QIcon::fromTheme("user-offline"), i18n("Disconnect"), this, SLOT(disconnectConnection()));
     }
     menu->addAction(actionCollection()->action("edit_connection"));
     menu->addAction(actionCollection()->action("delete_connection"));
@@ -388,22 +425,14 @@ void ConnectionEditor::slotItemClicked(const QModelIndex &index)
         return;
     }
 
-    qDebug() << "Clicked item" << index.data(NetworkModel::UuidRole).toString();
+//     qDebug() << "Clicked item" << index.data(NetworkModel::UuidRole).toString();
 
     if (index.parent().isValid()) { // category
-        actionCollection()->action("connect_connection")->setEnabled(false);
-        actionCollection()->action("disconnect_connection")->setEnabled(false);
         actionCollection()->action("edit_connection")->setEnabled(false);
         actionCollection()->action("delete_connection")->setEnabled(false);
         actionCollection()->action("export_vpn")->setEnabled(false);
         actionCollection()->action("export_vpn")->setEnabled(false);
     } else {                       //connection
-        const bool isActive = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
-        const bool isActivating = (NetworkManager::ActiveConnection::State)index.data(NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activating;
-        const bool isAvailable = (NetworkModelItem::ItemType)index.data(NetworkModel::ItemTypeRole).toUInt() == NetworkModelItem::AvailableConnection;
-
-        actionCollection()->action("connect_connection")->setEnabled(isAvailable && !isActive && !isActivating);
-        actionCollection()->action("disconnect_connection")->setEnabled(isAvailable && (isActive || isActivating));
         actionCollection()->action("edit_connection")->setEnabled(true);
         actionCollection()->action("delete_connection")->setEnabled(true);
         const bool isVpn = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(index.data(NetworkModel::TypeRole).toUInt()) ==
@@ -418,20 +447,29 @@ void ConnectionEditor::slotItemDoubleClicked(const QModelIndex &index)
         return;
     }
 
-    qDebug() << "Double clicked item" << index.data(NetworkModel::UuidRole).toString();
+//     qDebug() << "Double clicked item" << index.data(NetworkModel::UuidRole).toString();
 
     if (index.parent().isValid()) { // category
         qDebug() << "double clicked on the root item which is not editable";
         return;
     }
 
-    const QString uuid = index.data(NetworkModel::UuidRole).toString();
-    m_handler->editConnection(uuid);
+    NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(index.data(NetworkModel::UuidRole).toString());
+
+    QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(connection->settings(), false);
+
+    if (editor->exec() == QDialog::Accepted) {
+        m_handler->updateConnection(connection, editor->setting());
+    }
+
+    if (editor) {
+        editor->deleteLater();
+    }
 }
 
 void ConnectionEditor::importSecretsFromPlainTextFiles()
 {
-    const QString secretsDirectory = KStandardDirs::locateLocal("data", "networkmanagement/secrets/");
+    const QString secretsDirectory = QStandardPaths::locate(QStandardPaths::DataLocation, "networkmanagement/secrets/", QStandardPaths::LocateDirectory);
     QDir dir(secretsDirectory);
     if (dir.exists() && !dir.entryList(QDir::Files).isEmpty()) {
         QMap<QString, QMap<QString, QString > > resultingMap;
@@ -477,6 +515,17 @@ void ConnectionEditor::storeSecrets(const QMap< QString, QMap< QString, QString
                 }
             }
         }
+    } else {
+        KConfig config("plasma-networkmanagement");
+        foreach (const QString & groupName, map.keys()) {
+            KConfigGroup secretsGroup = config.group(groupName);
+            NMStringMap secretsMap = map.value(groupName);
+            NMStringMap::ConstIterator i = secretsMap.constBegin();
+            while (i != secretsMap.constEnd()) {
+                secretsGroup.writeEntry(i.key(), i.value());
+                ++i;
+            }
+        }
     }
 }
 
@@ -493,7 +542,7 @@ void ConnectionEditor::importVpn()
         }
     }
 
-    const QString filename = KFileDialog::getOpenFileName(KUrl(), extensions.simplified(), this, i18n("Import VPN Connection"));
+    const QString filename = QFileDialog::getOpenFileName(this, i18n("Import VPN Connection"), QDir::homePath(), extensions.simplified());
     if (!filename.isEmpty()) {
         QFileInfo fi(filename);
         const QString ext = QLatin1Literal("*.") % fi.suffix();
@@ -514,8 +563,8 @@ void ConnectionEditor::importVpn()
 
                 //qDebug() << "Converted connection:" << connectionSettings;
 
-                const QString conId = NetworkManager::addConnection(connectionSettings.toMap());
-                qDebug() << "Adding imported connection under id:" << conId;
+                m_handler->addConnection(connectionSettings.toMap());
+//                 qDebug() << "Adding imported connection under id:" << conId;
 
                 if (connection.isEmpty()) { // the "positive" part will arrive with connectionAdded
                     m_editor->messageWidget->animatedShow();
@@ -541,7 +590,7 @@ void ConnectionEditor::exportVpn()
         return;
     }
 
-    Connection::Ptr connection = NetworkManager::findConnectionByUuid(currentIndex.data(NetworkModel::UuidRole).toString());
+    NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(currentIndex.data(NetworkModel::UuidRole).toString());
     if (!connection) {
         return;
     }
@@ -569,8 +618,8 @@ void ConnectionEditor::exportVpn()
             return;
         }
 
-        const KUrl url = KUrl::fromLocalFile(KGlobalSettings::documentPath() + QDir::separator() + vpnPlugin->suggestedFileName(connSettings));
-        const QString filename = KFileDialog::getSaveFileName(url, vpnPlugin->supportedFileExtensions(), this, i18n("Export VPN Connection"));
+        const QString url = QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation) + QDir::separator() + vpnPlugin->suggestedFileName(connSettings);
+        const QString filename = QFileDialog::getSaveFileName(this, i18n("Export VPN Connection"), url, vpnPlugin->supportedFileExtensions());
         if (!filename.isEmpty()) {
             if (!vpnPlugin->exportConnectionSettings(connSettings, filename)) {
                 m_editor->messageWidget->animatedShow();
