@@ -30,7 +30,7 @@
 #include <KLocalizedString>
 #include <KNotification>
 #include <KIcon>
-#include <KDebug>
+#include <QDebug>
 
 Notification::Notification(QObject *parent) :
     QObject(parent)
@@ -65,7 +65,7 @@ void Notification::addDevice(const NetworkManager::Device::Ptr &device)
 void Notification::stateChanged(NetworkManager::Device::State newstate, NetworkManager::Device::State oldstate, NetworkManager::Device::StateChangeReason reason)
 {
     Q_UNUSED(oldstate)
-    kDebug() << newstate << reason;
+    qDebug() << newstate << reason;
     NetworkManager::Device *device = qobject_cast<NetworkManager::Device*>(sender());
     if (newstate == NetworkManager::Device::Activated && m_notifications.contains(device->uni())) {
         KNotification *notify = m_notifications.value(device->uni());
@@ -284,7 +284,7 @@ void Notification::stateChanged(NetworkManager::Device::State newstate, NetworkM
     case NetworkManager::Device::Reserved:
         return;
     }
-    kDebug() << text;
+    qDebug() << text;
 
     if (m_notifications.contains(device->uni())) {
         KNotification *notify = m_notifications.value(device->uni());
@@ -294,7 +294,7 @@ void Notification::stateChanged(NetworkManager::Device::State newstate, NetworkM
         KNotification *notify = new KNotification("DeviceFailed", KNotification::CloseOnTimeout, this);
         connect(notify, SIGNAL(closed()), this, SLOT(notificationClosed()));
         notify->setProperty("uni", device->uni());
-        notify->setComponentData(KComponentData("networkmanagement"));
+        notify->setComponentName("networkmanagement");
         notify->setPixmap(KIcon("dialog-warning").pixmap(64, 64));
         notify->setTitle(identifier);
         notify->setText(text);
@@ -338,14 +338,14 @@ void Notification::onActiveConnectionStateChanged(NetworkManager::ActiveConnecti
         eventId = "ConnectionDeactivated";
         text = i18n("Connection '%1' deactivated.", acName);
     } else {
-        kDebug() << "Unhandled active connection state change: " << state;
+        qDebug() << "Unhandled active connection state change: " << state;
         return;
     }
 
     KNotification *notify = new KNotification(eventId, KNotification::CloseOnTimeout, this);
     connect(notify, SIGNAL(closed()), this, SLOT(notificationClosed()));
     notify->setProperty("uni", connectionId);
-    notify->setComponentData(KComponentData("networkmanagement"));
+    notify->setComponentName("networkmanagement");
     if (state == NetworkManager::ActiveConnection::Activated) {
         notify->setPixmap(KIcon("dialog-information").pixmap(64, 64));
     } else {
@@ -375,7 +375,7 @@ void Notification::onVpnConnectionStateChanged(NetworkManager::VpnConnection::St
         eventId = "ConnectionDeactivated";
         text = i18n("VPN connection '%1' disconnected.", vpnName);
     } else {
-        kDebug() << "Unhandled VPN connection state change: " << state;
+        qDebug() << "Unhandled VPN connection state change: " << state;
         return;
     }
 
@@ -419,7 +419,7 @@ void Notification::onVpnConnectionStateChanged(NetworkManager::VpnConnection::St
     KNotification *notify = new KNotification(eventId, KNotification::CloseOnTimeout, this);
     connect(notify, SIGNAL(closed()), this, SLOT(notificationClosed()));
     notify->setProperty("uni", connectionId);
-    notify->setComponentData(KComponentData("networkmanagement"));
+    notify->setComponentName("networkmanagement");
     if (state == NetworkManager::VpnConnection::Activated) {
         notify->setPixmap(KIcon("dialog-information").pixmap(64, 64));
     } else {
