@@ -28,13 +28,14 @@
 #include <NetworkManagerQt/VpnSetting>
 
 #include <KServiceTypeTrader>
+#include <KLocalizedString>
 #include <KIcon>
-#include <KDebug>
+#include <QDebug>
 
 using namespace NetworkManager;
 
 PasswordDialog::PasswordDialog(const NMVariantMapMap &connection, SecretAgent::GetSecretsFlags flags, const QString &setting_name, QWidget *parent) :
-    KDialog(parent),
+    QDialog(parent),
     ui(0),
     vpnWidget(0),
     m_connection(connection),
@@ -56,13 +57,13 @@ void PasswordDialog::setupGenericUi(const ConnectionSettings &connectionSettings
     NetworkManager::Setting::Ptr setting = connectionSettings.setting(m_settingName);
 
     ui = new Ui::PasswordDialog;
-    ui->setupUi(mainWidget());
+    ui->setupUi(this);
     // TODO fix this for high DPI
     ui->labelIcon->setPixmap(KIcon("dialog-password").pixmap(32));
 
     m_neededSecrets = setting->needSecrets(m_flags & SecretAgent::RequestNew);
     if (m_neededSecrets.isEmpty()) {
-        kWarning() << "list of secrets is empty!!!";
+        qWarning() << "list of secrets is empty!!!";
         m_hasError = true;
         m_error = SecretAgent::InternalError;
         m_errorMessage = QLatin1String("No secrets were requested");
@@ -74,15 +75,17 @@ void PasswordDialog::setupGenericUi(const ConnectionSettings &connectionSettings
 
     Setting::SettingType connectionType = setting->type();
     if (wifi && (connectionType == Setting::WirelessSecurity || connectionType == Setting::Security8021x)) {
-        const QString ssid = QString::fromUtf8(wifi->ssid());
+        const QString ssid = wifi->ssid();
         ui->labelText->setText(i18n("For accessing the wireless network '%1' you need to provide a password below", ssid));
     } else {
-        ui->labelText->setText(i18n("Please provide the password for activating connection '%1'", connectionSettings.id()));
+        ui->labelText->setText(i18n("Please provide the password for activating connection '%1'", connectionSettings.name()));
     }
 
     ui->password->setPasswordMode(true);
     ui->password->setFocus();
-    connect(ui->showPassword, SIGNAL(toggled(bool)), this, SLOT(showPassword(bool)));
+    connect(ui->showPassword, &QCheckBox::toggled, this, &PasswordDialog::showPassword);
+    connect(ui->buttonBox, &QDialogButtonBox::accepted, this, &PasswordDialog::accept);
+    connect(ui->buttonBox, &QDialogButtonBox::rejected, this, &PasswordDialog::reject);
 }
 
 void PasswordDialog::setupVpnUi(const ConnectionSettings &connectionSettings)
@@ -90,7 +93,7 @@ void PasswordDialog::setupVpnUi(const ConnectionSettings &connectionSettings)
     NetworkManager::VpnSetting::Ptr vpnSetting;
     vpnSetting = connectionSettings.setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
     if (!vpnSetting) {
-        kDebug() << "Missing VPN setting!";
+        qDebug() << "Missing VPN setting!";
         m_hasError = true;
         m_error = SecretAgent::InternalError;
         m_errorMessage = QLatin1String("VPN settings are missing");
@@ -105,11 +108,13 @@ void PasswordDialog::setupVpnUi(const ConnectionSettings &connectionSettings)
                                                                                this, QVariantList(), &error);
         if (vpnUiPlugin && error.isEmpty()) {
             const QString shortName = serviceType.section('.', -1);
-            setCaption(i18n("VPN secrets (%1)", shortName));
+            setWindowTitle(i18n("VPN secrets (%1)", shortName));
             vpnWidget = vpnUiPlugin->askUser(vpnSetting, this);
-            setMainWidget(vpnWidget);
+            QVBoxLayout * layout = new QVBoxLayout(this);
+            layout->addWidget(vpnWidget);
+            setLayout(layout);
         } else {
-            kDebug() << error << ", serviceType == " << serviceType;
+            qDebug() << error << ", serviceType == " << serviceType;
             m_hasError = true;
             m_error = SecretAgent::InternalError;
             m_errorMessage = error;
