@@ -2,7 +2,6 @@
     Copyright 2009 Dario Freddi <drf54321@gmail.com>
     Copyright 2009 Will Stephenson <wstephenson@kde.org>
     Copyright 2011-2012 Lamarque V. Souza <lamarque@kde.org>
-    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -24,6 +23,7 @@
 #include "service.h"
 
 #include <KPluginFactory>
+#include <KGlobal>
 
 #include "secretagent.h"
 #include "notification.h"
@@ -39,33 +39,23 @@
 #include <QDBusReply>
 
 K_PLUGIN_FACTORY(NetworkManagementServiceFactory, registerPlugin<NetworkManagementService>();)
-K_EXPORT_PLUGIN(NetworkManagementServiceFactory("networkmanagement", "plasmanetworkmanagement-kded"))
 
 class NetworkManagementServicePrivate
 {
-public:
+    public:
     SecretAgent * agent;
-    BluetoothMonitor * bluetoothMonitor;
-#if WITH_MODEMMANAGER_SUPPORT
-    ModemMonitor * modemMonitor;
-#endif
-    Notification * notification;
 };
 
 NetworkManagementService::NetworkManagementService(QObject * parent, const QVariantList&)
-        : KDEDModule(parent), d_ptr(new NetworkManagementServicePrivate)
+    : KDEDModule(parent), d_ptr(new NetworkManagementServicePrivate)
 {
-    Q_D(NetworkManagementService);
-
-    d->agent = 0;
-    d->notification = 0;
-
-#if WITH_MODEMMANAGER_SUPPORT
-    d->modemMonitor = 0;
-#endif
-    d->bluetoothMonitor = 0;
-
-    connect(this, SIGNAL(moduleRegistered(QDBusObjectPath)), this, SLOT(slotRegistered(QDBusObjectPath)));
+    QDBusReply<bool> reply = QDBusConnection::sessionBus().interface()->isServiceRegistered("org.kde.plasmashell");
+    if (reply.value()) {
+        doInitialization();
+    } else {
+        QDBusServiceWatcher * watcher = new QDBusServiceWatcher("org.kde.plasmashell", QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
+        connect(watcher, SIGNAL(serviceRegistered(QString)), SLOT(finishInitialization()));
+    }
 }
 
 NetworkManagementService::~NetworkManagementService()
@@ -73,33 +63,25 @@ NetworkManagementService::~NetworkManagementService()
     delete d_ptr;
 }
 
-void NetworkManagementService::init()
+void NetworkManagementService::finishInitialization()
+{
+    QDBusServiceWatcher * watcher = static_cast<QDBusServiceWatcher*>(sender());
+    disconnect(watcher, SIGNAL(serviceRegistered(QString)), this, SLOT(finishInitialization()));
+
+    doInitialization();
+}
+
+void NetworkManagementService::doInitialization()
 {
     Q_D(NetworkManagementService);
 
-    if (!d->agent) {
-        d->agent = new SecretAgent(this);
-    }
-
-    if (!d->notification) {
-        d->notification = new Notification(this);
-    }
-
+    qDebug() << "Doing initialization";
+    d->agent = new SecretAgent(this);
+    new Notification(this);
 #if WITH_MODEMMANAGER_SUPPORT
-    if (!d->modemMonitor) {
-        d->modemMonitor = new ModemMonitor(this);
-    }
+    new ModemMonitor(this);
 #endif
-
-    if (!d->bluetoothMonitor) {
-        d->bluetoothMonitor = new BluetoothMonitor(this);
-    }
-}
-void NetworkManagementService::slotRegistered(const QDBusObjectPath &path)
-{
-    if (path.path() == QLatin1String("/modules/networkmanagement")) {
-        Q_EMIT registered();
-    }
+    new BluetoothMonitor(this);
 }
 
 #include "service.moc"
