@@ -30,6 +30,11 @@
 #include <NetworkManagerQt/WirelessDevice>
 #include <NetworkManagerQt/WirelessSetting>
 
+#if WITH_MODEMMANAGER_SUPPORT
+#include <ModemManagerQt/manager.h>
+#include <ModemManagerQt/modem.h>
+#endif
+
 ConnectionIcon::ConnectionIcon(QObject* parent)
     : QObject(parent)
     , m_signal(0)
@@ -73,14 +78,6 @@ ConnectionIcon::ConnectionIcon(QObject* parent)
                 connect(wiredDevice.data(), SIGNAL(carrierChanged(bool)),
                         SLOT(carrierChanged(bool)));
             }
-        } else if (device->type() == NetworkManager::Device::Wifi) {
-            NetworkManager::WirelessDevice::Ptr wifiDevice = device.staticCast<NetworkManager::WirelessDevice>();
-            if (wifiDevice) {
-                connect(wifiDevice.data(), SIGNAL(availableConnectionAppeared(QString)),
-                        SLOT(wirelessNetworkAppeared(QString)));
-                connect(wifiDevice.data(), SIGNAL(networkAppeared(QString)),
-                        SLOT(wirelessNetworkAppeared(QString)));
-            }
         }
     }
 
@@ -295,14 +292,6 @@ void ConnectionIcon::wirelessEnabledChanged(bool enabled)
     }
 }
 
-void ConnectionIcon::wirelessNetworkAppeared(const QString& network)
-{
-    Q_UNUSED(network);
-    if (NetworkManager::status() == NetworkManager::Disconnected) {
-        setDisconnectedIcon();
-    }
-}
-
 void ConnectionIcon::wwanEnabledChanged(bool enabled)
 {
     Q_UNUSED(enabled);
@@ -333,36 +322,17 @@ void ConnectionIcon::setIcons()
     // Workaround, because PrimaryConnection is kinda broken in NM 0.9.8.x and
     // doesn't work correctly with some VPN connections. This shouldn't be necessary
     // for NM 0.9.9.0 or the upcoming bugfix release NM 0.9.8.10
-#if !NM_CHECK_VERSION(0, 9, 10)
     if (!connection) {
-        bool defaultRoute = false;
-        NetworkManager::ActiveConnection::Ptr mainActiveConnection;
-        Q_FOREACH (const NetworkManager::ActiveConnection::Ptr & activeConnection, NetworkManager::activeConnections()) {
+        foreach (const NetworkManager::ActiveConnection::Ptr & activeConnection, NetworkManager::activeConnections()) {
             if ((activeConnection->default4() || activeConnection->default6()) && activeConnection->vpn()) {
-                defaultRoute = true;
-                mainActiveConnection = activeConnection;
-                break;
-            }
-        }
-
-        if (!defaultRoute) {
-            Q_FOREACH (const NetworkManager::ActiveConnection::Ptr & activeConnection, NetworkManager::activeConnections()) {
-                if (activeConnection->vpn()) {
-                    mainActiveConnection = activeConnection;
-                    break;
+                NetworkManager::ActiveConnection::Ptr baseActiveConnection;
+                baseActiveConnection = NetworkManager::findActiveConnection(activeConnection->specificObject());
+                if (baseActiveConnection) {
+                    connection = baseActiveConnection;
                 }
             }
         }
-
-        if (mainActiveConnection) {
-            NetworkManager::ActiveConnection::Ptr baseActiveConnection;
-            baseActiveConnection = NetworkManager::findActiveConnection(mainActiveConnection->specificObject());
-            if (baseActiveConnection) {
-                connection = baseActiveConnection;
-            }
-        }
     }
-#endif
 
     if (connection && !connection->devices().isEmpty()) {
         NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(connection->devices().first());
@@ -449,10 +419,7 @@ void ConnectionIcon::setDisconnectedIcon()
         } else if (device->type() == NetworkManager::Device::Wifi &&
                    NetworkManager::isWirelessEnabled() &&
                    NetworkManager::isWirelessHardwareEnabled()) {
-            NetworkManager::WirelessDevice::Ptr wifiDevice = device.objectCast<NetworkManager::WirelessDevice>();
-            if (!wifiDevice->accessPoints().isEmpty() || !wifiDevice->availableConnections().isEmpty()) {
-                wireless = true;
-            }
+            wireless = true;
         } else if (device->type() == NetworkManager::Device::Modem &&
                    NetworkManager::isWwanEnabled() &&
                    NetworkManager::isWwanHardwareEnabled()) {
@@ -498,7 +465,12 @@ void ConnectionIcon::setModemIcon(const NetworkManager::Device::Ptr & device)
         return;
     }
 
-    m_modemNetwork = modemDevice->getModemNetworkIface();
+    ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(device->udi());
+    if (modem) {
+        if (modem->hasInterface(ModemManager::ModemDevice::ModemInterface)) {
+            m_modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+        }
+    }
 
     if (m_modemNetwork) {
         connect(m_modemNetwork.data(), SIGNAL(signalQualityChanged(uint)),
@@ -602,34 +574,41 @@ void ConnectionIcon::setWirelessIcon(const NetworkManager::Device::Ptr &device,
 
 void ConnectionIcon::setWirelessIconForSignalStrength(int strength)
 {
-    int iconStrength = 100;
-    if (strength == 0) {
-        iconStrength = 0;
-        m_connectionTooltipIcon = "network-wireless-connected-00";
-        Q_EMIT connectionTooltipIconChanged("network-wireless-connected-00");
-    } else if (strength < 20) {
-        iconStrength = 20;
-        m_connectionTooltipIcon = "network-wireless-connected-20";
-        Q_EMIT connectionTooltipIconChanged("network-wireless-connected-20");
-    } else if (strength < 40) {
-        iconStrength = 40;
-        m_connectionTooltipIcon = "network-wireless-connected-40";
-        Q_EMIT connectionTooltipIconChanged("network-wireless-connected-40");
-    } else if (strength < 60) {
-        iconStrength = 60;
-        m_connectionTooltipIcon = "network-wireless-connected-60";
-        Q_EMIT connectionTooltipIconChanged("network-wireless-connected-60");
-    } else if (strength < 80) {
-        iconStrength = 80;
-        m_connectionTooltipIcon = "network-wireless-connected-80";
-        Q_EMIT connectionTooltipIconChanged("network-wireless-connected-80");
-    } else if (strength < 100) {
-        m_connectionTooltipIcon = "network-wireless-connected-100";
-        Q_EMIT connectionTooltipIconChanged("network-wireless-connected-100");
+    const int diff = m_signal - strength;
+
+    if (diff >= 10 || diff <= -10) {
+        int iconStrength = 100;
+
+        if (strength == 0) {
+            iconStrength = 0;
+            m_connectionTooltipIcon = "network-wireless-connected-00";
+            Q_EMIT connectionTooltipIconChanged("network-wireless-connected-00");
+        } else if (strength < 20) {
+            iconStrength = 20;
+            m_connectionTooltipIcon = "network-wireless-connected-20";
+            Q_EMIT connectionTooltipIconChanged("network-wireless-connected-20");
+        } else if (strength < 40) {
+            iconStrength = 40;
+            m_connectionTooltipIcon = "network-wireless-connected-40";
+            Q_EMIT connectionTooltipIconChanged("network-wireless-connected-40");
+        } else if (strength < 60) {
+            iconStrength = 60;
+            m_connectionTooltipIcon = "network-wireless-connected-60";
+            Q_EMIT connectionTooltipIconChanged("network-wireless-connected-60");
+        } else if (strength < 80) {
+            iconStrength = 80;
+            m_connectionTooltipIcon = "network-wireless-connected-80";
+            Q_EMIT connectionTooltipIconChanged("network-wireless-connected-80");
+        } else if (strength < 100) {
+            m_connectionTooltipIcon = "network-wireless-connected-100";
+            Q_EMIT connectionTooltipIconChanged("network-wireless-connected-100");
+        }
+
+        m_signal = iconStrength;
+
+        QString icon = QString("network-wireless-%1").arg(iconStrength);
+
+        m_connectionIcon = icon;
+        Q_EMIT connectionIconChanged(icon);
     }
-
-    QString icon = QString("network-wireless-%1").arg(iconStrength);
-
-    m_connectionIcon = icon;
-    Q_EMIT connectionIconChanged(icon);
 }
