@@ -130,12 +130,7 @@ void NetworkStatus::changeActiveConnections()
         if (!active->devices().isEmpty()) {
             NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(active->devices().first());
 
-#if NM_CHECK_VERSION(0, 9, 10)
-            if (device && ((device->type() >= NetworkManager::Device::Ethernet && device->type() <= NetworkManager::Device::Wifi) ||
-                          ((device->type() >= NetworkManager::Device::Bluetooth && device->type() <= NetworkManager::Device::Bridge)))) {
-#else
             if (device) {
-#endif
                 QString devName;
                 QString conType;
                 QString status;
@@ -155,9 +150,9 @@ void NetworkStatus::changeActiveConnections()
                     status = i18n("Connecting to %1", active->connection()->name());
                 }
                 if (active->default4() || active->default6()) {
-                    activeConnections += QString(formatDefault).arg(devName, conType, status);
+                    activeConnections += formatDefault.arg(devName, conType, status);
                 } else {
-                    activeConnections += QString(format).arg(devName, conType, status);
+                    activeConnections += format.arg(devName, conType, status);
                 }
             }
         }
