@@ -34,144 +34,46 @@
 #include "settings/pppwidget.h"
 #include "settings/pppoewidget.h"
 #include "settings/vlanwidget.h"
-#include "settings/wimaxwidget.h"
-#include "settings/wiredsecurity.h"
-#include "settings/wiredconnectionwidget.h"
-#include "settings/wifisecurity.h"
 #include "settings/wificonnectionwidget.h"
-#include "vpn/openvpn/nm-openvpn-service.h"
+#include "settings/wifisecurity.h"
+#include "settings/wiredconnectionwidget.h"
+#include "settings/wiredsecurity.h"
+#include "settings/wimaxwidget.h"
+#if NM_CHECK_VERSION(0, 9, 10)
+#include "settings/teamwidget.h"
+#endif
 #include "vpnuiplugin.h"
 
 #include <NetworkManagerQt/ActiveConnection>
 #include <NetworkManagerQt/AdslSetting>
-#include <NetworkManagerQt/CdmaSetting>
 #include <NetworkManagerQt/Connection>
+#include <NetworkManagerQt/CdmaSetting>
 #include <NetworkManagerQt/GenericTypes>
 #include <NetworkManagerQt/GsmSetting>
 #include <NetworkManagerQt/PppoeSetting>
 #include <NetworkManagerQt/Settings>
-#include <NetworkManagerQt/Utils>
 #include <NetworkManagerQt/VpnSetting>
+#include <NetworkManagerQt/Utils>
 #include <NetworkManagerQt/WirelessSetting>
 #include <NetworkManagerQt/WirelessDevice>
 
 #include <QDebug>
+#include <QPushButton>
 
+#include <KIcon>
 #include <KUser>
+#include <KNotification>
+#include <KLocalizedString>
 #include <KPluginFactory>
 #include <KServiceTypeTrader>
-#include <QPushButton>
-#include <KWallet/Wallet>
 
-using namespace NetworkManager;
-
-ConnectionDetailEditor::ConnectionDetailEditor(NetworkManager::ConnectionSettings::ConnectionType type, QWidget* parent,
-                                               const QString &masterUuid, const QString &slaveType, Qt::WindowFlags f):
-    QDialog(parent, f),
-    m_ui(new Ui::ConnectionDetailEditor),
-    m_connection(new NetworkManager::ConnectionSettings(type)),
-    m_new(true),
-    m_masterUuid(masterUuid),
-    m_slaveType(slaveType)
+ConnectionDetailEditor::ConnectionDetailEditor(const NetworkManager::ConnectionSettings::Ptr& connection,
+                                               bool newConnection, QWidget* parent, Qt::WindowFlags f)
+    : QDialog(parent, f)
+    , m_connection(connection)
+    , m_new(newConnection)
+    , m_ui(new Ui::ConnectionDetailEditor)
 {
-    setAttribute(Qt::WA_DeleteOnClose);
-    m_ui->setupUi(this);
-
-    initEditor();
-}
-
-ConnectionDetailEditor::ConnectionDetailEditor(NetworkManager::ConnectionSettings::ConnectionType type, QWidget* parent,
-                                               const QString &vpnType, bool shared, Qt::WindowFlags f):
-    QDialog(parent, f),
-    m_ui(new Ui::ConnectionDetailEditor),
-    m_connection(new NetworkManager::ConnectionSettings(type)),
-    m_new(true),
-    m_vpnType(vpnType)
-{
-    setAttribute(Qt::WA_DeleteOnClose);
-    m_ui->setupUi(this);
-
-    if (shared) {
-        if (type == ConnectionSettings::Wireless) {
-            NetworkManager::WirelessSetting::Ptr wifiSetting = m_connection->setting(Setting::Wireless).dynamicCast<NetworkManager::WirelessSetting>();
-            wifiSetting->setMode(WirelessSetting::Adhoc);
-            wifiSetting->setSsid(i18n("my_shared_connection").toUtf8());
-
-            foreach (const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
-                if (device->type() == Device::Wifi) {
-                    NetworkManager::WirelessDevice::Ptr wifiDev = device.objectCast<NetworkManager::WirelessDevice>();
-                    if (wifiDev) {
-                        if (wifiDev->wirelessCapabilities().testFlag(WirelessDevice::ApCap)) {
-                            wifiSetting->setMode(WirelessSetting::Ap);
-                            wifiSetting->setMacAddress(Utils::macAddressFromString(wifiDev->hardwareAddress()));
-                        }
-                    }
-                }
-            }
-        }
-        NetworkManager::Ipv4Setting::Ptr ipv4Setting = m_connection->setting(Setting::Ipv4).dynamicCast<NetworkManager::Ipv4Setting>();
-        ipv4Setting->setMethod(Ipv4Setting::Shared);
-        m_connection->setAutoconnect(false);
-    }
-
-    initEditor();
-}
-
-ConnectionDetailEditor::ConnectionDetailEditor(ConnectionSettings::ConnectionType type, const QVariantList &args, QWidget *parent, Qt::WindowFlags f):
-    QDialog(parent, f),
-    m_ui(new Ui::ConnectionDetailEditor),
-    m_connection(new NetworkManager::ConnectionSettings(type)),
-    m_new(true)
-{
-    setAttribute(Qt::WA_DeleteOnClose);
-    m_ui->setupUi(this);
-
-    // parse args given from the wizard
-    qDebug() << "Editing new mobile connection, number of args:" << args.count();
-    foreach(const QVariant & arg, args) {
-        qDebug() << "Argument:" << arg;
-    }
-
-    if (args.count() == 2) { //GSM or CDMA
-        QVariantMap tmp = qdbus_cast<QVariantMap>(args.value(1));
-
-#if 0 // network IDs are not used yet and seem to break the setting
-        if (args.count() == 3) { // gsm specific
-            QStringList networkIds = args.value(1).toStringList();
-            if (!networkIds.isEmpty())
-                tmp.insert("network-id", networkIds.first());
-        }
-#endif
-
-        m_connection->setConnectionType(type);
-        m_connection->setId(args.value(0).toString());
-        qDebug() << "New " << m_connection->typeAsString(m_connection->connectionType()) << "connection initializing with:" << tmp;
-        if (type == ConnectionSettings::Gsm)
-            m_connection->setting(Setting::Gsm)->fromMap(tmp);
-        else if (type == ConnectionSettings::Cdma)
-            m_connection->setting(Setting::Cdma)->fromMap(tmp);
-        else
-            qWarning() << Q_FUNC_INFO << "Unhandled setting type";
-
-        qDebug() << "New connection initialized:";
-        qDebug() << *m_connection;
-    } else {
-        qWarning() << Q_FUNC_INFO << "Unexpected number of args to parse";
-    }
-
-    initEditor();
-}
-
-
-ConnectionDetailEditor::ConnectionDetailEditor(const NetworkManager::ConnectionSettings::Ptr &connection, QWidget* parent, Qt::WindowFlags f, bool newConnection):
-    QDialog(parent, f),
-    m_ui(new Ui::ConnectionDetailEditor),
-    m_connection(connection),
-    m_new(newConnection),
-    m_masterUuid(connection->master()),
-    m_slaveType(connection->slaveType())
-{
-    setAttribute(Qt::WA_DeleteOnClose);
     m_ui->setupUi(this);
 
     initEditor();
@@ -191,68 +93,70 @@ void ConnectionDetailEditor::initEditor()
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(m_connection->uuid());
         if (connection) {
             bool hasSecrets = false;
-            connect(connection.data(), SIGNAL(gotSecrets(QString,bool,NMVariantMapMap,QString)),
-                    SLOT(gotSecrets(QString,bool,NMVariantMapMap,QString)), Qt::UniqueConnection);
+            QDBusPendingReply<NMVariantMapMap> reply;
 
             if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Adsl) {
                 NetworkManager::AdslSetting::Ptr adslSetting = connection->settings()->setting(NetworkManager::Setting::Adsl).staticCast<NetworkManager::AdslSetting>();
                 if (adslSetting && !adslSetting->needSecrets().isEmpty()) {
                     hasSecrets = true;
-                    connection->secrets("adsl");
+                    reply = connection->secrets("adsl");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Bluetooth) {
                 NetworkManager::GsmSetting::Ptr gsmSetting = connection->settings()->setting(NetworkManager::Setting::Gsm).staticCast<NetworkManager::GsmSetting>();
                 if (gsmSetting && !gsmSetting->needSecrets().isEmpty()) {
                     hasSecrets = true;
-                    connection->secrets("gsm");
+                    reply = connection->secrets("gsm");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Cdma) {
                 NetworkManager::CdmaSetting::Ptr cdmaSetting = connection->settings()->setting(NetworkManager::Setting::Cdma).staticCast<NetworkManager::CdmaSetting>();
                 if (cdmaSetting && !cdmaSetting->needSecrets().isEmpty()) {
                     hasSecrets = true;
-                    connection->secrets("cdma");
+                    reply = connection->secrets("cdma");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Gsm) {
                 NetworkManager::GsmSetting::Ptr gsmSetting = connection->settings()->setting(NetworkManager::Setting::Gsm).staticCast<NetworkManager::GsmSetting>();
                 if (gsmSetting && !gsmSetting->needSecrets().isEmpty()) {
                     hasSecrets = true;
-                    connection->secrets("gsm");
+                    reply = connection->secrets("gsm");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Pppoe) {
                 NetworkManager::PppoeSetting::Ptr pppoeSetting = connection->settings()->setting(NetworkManager::Setting::Pppoe).staticCast<NetworkManager::PppoeSetting>();
                 if (pppoeSetting && !pppoeSetting->needSecrets().isEmpty()) {
                     hasSecrets = true;
-                    connection->secrets("pppoe");
+                    reply = connection->secrets("pppoe");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Wired) {
                 NetworkManager::Security8021xSetting::Ptr securitySetting = connection->settings()->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>();
                 if (securitySetting && !securitySetting->needSecrets().isEmpty()) {
                     hasSecrets = true;
-                    connection->secrets("802-1x");
+                    reply = connection->secrets("802-1x");
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
                 NetworkManager::WirelessSecuritySetting::Ptr wifiSecuritySetting = connection->settings()->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
                 if (wifiSecuritySetting &&
                     (wifiSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WpaEap ||
-                    (wifiSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting::Ieee8021x &&
-                     wifiSecuritySetting->authAlg() != WirelessSecuritySetting::Leap))) {
+                    wifiSecuritySetting->keyMgmt() == NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting::Ieee8021x)) {
                     NetworkManager::Security8021xSetting::Ptr securitySetting = connection->settings()->setting(NetworkManager::Setting::Security8021x).staticCast<NetworkManager::Security8021xSetting>();
                     if (securitySetting && !securitySetting->needSecrets().isEmpty()) {
                         hasSecrets = true;
-                        connection->secrets("802-1x");
+                        reply = connection->secrets("802-1x");
                     }
                 } else {
                     if (!wifiSecuritySetting->needSecrets().isEmpty()) {
                         hasSecrets = true;
-                        connection->secrets("802-11-wireless-security");
+                        reply = connection->secrets("802-11-wireless-security");
                     }
                 }
             } else if (m_connection->connectionType() == NetworkManager::ConnectionSettings::Vpn) {
                 hasSecrets = true;
-                connection->secrets("vpn");
+                reply = connection->secrets("vpn");
             }
 
-            if (!hasSecrets) {
+            if (hasSecrets) {
+                QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+                watcher->setProperty("connection", connection->name());
+                connect(watcher, &QDBusPendingCallWatcher::finished, this, &ConnectionDetailEditor::replyFinished);
+            } else {
                 initTabs();
             }
         }
@@ -267,10 +171,6 @@ void ConnectionDetailEditor::initEditor()
         setWindowTitle(i18n("Edit Connection '%1'", m_connection->id()));
         m_ui->connectionName->setText(m_connection->id());
     }
-
-    connect(this, SIGNAL(accepted()), SLOT(saveSetting()));
-    connect(this, SIGNAL(accepted()), SLOT(disconnectSignals()));
-    connect(this, SIGNAL(rejected()), SLOT(disconnectSignals()));
 }
 
 void ConnectionDetailEditor::initTabs()
@@ -279,22 +179,14 @@ void ConnectionDetailEditor::initTabs()
         m_connection->addToPermissions(KUser().loginName(), QString());
     }
 
-    // create/set UUID, need this beforehand for slave connections
-    QString uuid = m_connection->uuid();
-    if (QUuid(uuid).isNull()) {
-        uuid = NetworkManager::ConnectionSettings::createNewUuid();
-        m_connection->setUuid(uuid);
-    }
-
     ConnectionWidget * connectionWidget = new ConnectionWidget(m_connection);
     m_ui->tabWidget->addTab(connectionWidget, i18nc("General", "General configuration"));
 
-    qDebug() << "Initting tabs, UUID:" << uuid;
+//     qDebug() << "Initting tabs, UUID:" << m_connection->uuid();
 
     const NetworkManager::ConnectionSettings::ConnectionType type = m_connection->connectionType();
 
     // setup the widget tabs
-    QString serviceType;
     if (type == NetworkManager::ConnectionSettings::Wired) {
         WiredConnectionWidget * wiredWidget = new WiredConnectionWidget(m_connection->setting(NetworkManager::Setting::Wired), this);
         m_ui->tabWidget->addTab(wiredWidget, i18n("Wired"));
@@ -328,18 +220,24 @@ void ConnectionDetailEditor::initTabs()
             PPPWidget * pppWidget = new PPPWidget(m_connection->setting(NetworkManager::Setting::Ppp), this);
             m_ui->tabWidget->addTab(pppWidget, i18n("PPP"));
         }
+
     } else if (type == NetworkManager::ConnectionSettings::Infiniband) { // Infiniband
         InfinibandWidget * infinibandWidget = new InfinibandWidget(m_connection->setting(NetworkManager::Setting::Infiniband), this);
         m_ui->tabWidget->addTab(infinibandWidget, i18n("Infiniband"));
     } else if (type == NetworkManager::ConnectionSettings::Bond) { // Bond
-        BondWidget * bondWidget = new BondWidget(uuid, m_connection->setting(NetworkManager::Setting::Bond), this);
+        BondWidget * bondWidget = new BondWidget(m_connection->uuid(), m_connection->setting(NetworkManager::Setting::Bond), this);
         m_ui->tabWidget->addTab(bondWidget, i18n("Bond"));
     } else if (type == NetworkManager::ConnectionSettings::Bridge) { // Bridge
-        BridgeWidget * bridgeWidget = new BridgeWidget(uuid, m_connection->setting(NetworkManager::Setting::Bridge), this);
+        BridgeWidget * bridgeWidget = new BridgeWidget(m_connection->uuid(), m_connection->setting(NetworkManager::Setting::Bridge), this);
         m_ui->tabWidget->addTab(bridgeWidget, i18n("Bridge"));
-    } else if (type == NetworkManager::ConnectionSettings::Vlan) { // Vlan
+   } else if (type == NetworkManager::ConnectionSettings::Vlan) { // Vlan
         VlanWidget * vlanWidget = new VlanWidget(m_connection->setting(NetworkManager::Setting::Vlan), this);
         m_ui->tabWidget->addTab(vlanWidget, i18n("Vlan"));
+#if NM_CHECK_VERSION(0, 9, 10)
+    } else if (type == NetworkManager::ConnectionSettings::Team) { // Team
+        TeamWidget * teamWidget = new TeamWidget(m_connection->uuid(), m_connection->setting(NetworkManager::Setting::Team), this);
+        m_ui->tabWidget->addTab(teamWidget, i18n("Team"));
+#endif
     } else if (type == NetworkManager::ConnectionSettings::Wimax) { // Wimax
         WimaxWidget * wimaxWidget = new WimaxWidget(m_connection->setting(NetworkManager::Setting::Wimax), this);
         m_ui->tabWidget->addTab(wimaxWidget, i18n("WiMAX"));
@@ -351,12 +249,7 @@ void ConnectionDetailEditor::initTabs()
         if (!vpnSetting) {
             qDebug() << "Missing VPN setting!";
         } else {
-            if (m_new && !m_vpnType.isEmpty()) {
-                serviceType = m_vpnType;
-                vpnSetting->setServiceType(serviceType);
-            }
-            else
-                serviceType = vpnSetting->serviceType();
+            QString serviceType = vpnSetting->serviceType();
             //qDebug() << "Editor loading VPN plugin" << serviceType;
             //vpnSetting->printSetting();
             vpnPlugin = KServiceTypeTrader::createInstanceFromQuery<VpnUiPlugin>(QString::fromLatin1("PlasmaNetworkManagement/VpnUiPlugin"),
@@ -373,26 +266,30 @@ void ConnectionDetailEditor::initTabs()
     }
 
     // PPP widget
-    if (type == ConnectionSettings::Pppoe || type == ConnectionSettings::Cdma || type == ConnectionSettings::Gsm) {
+    if (type == NetworkManager::ConnectionSettings::Pppoe || type == NetworkManager::ConnectionSettings::Cdma || type == NetworkManager::ConnectionSettings::Gsm) {
         PPPWidget * pppWidget = new PPPWidget(m_connection->setting(NetworkManager::Setting::Ppp), this);
         m_ui->tabWidget->addTab(pppWidget, i18n("PPP"));
     }
 
-    // IPv4 widget
-    if (!isSlave()) {
+    // TODO virtual connections
+//     IPv4 widget
+    if (!m_connection->isSlave()) {
         IPv4Widget * ipv4Widget = new IPv4Widget(m_connection->setting(NetworkManager::Setting::Ipv4), this);
         m_ui->tabWidget->addTab(ipv4Widget, i18n("IPv4"));
     }
 
+    // TODO virtual connections
     // IPv6 widget
-    if ((type == ConnectionSettings::Wired
-         || type == ConnectionSettings::Wireless
-         || type == ConnectionSettings::Infiniband
-         || type == ConnectionSettings::Wimax
-         || type == ConnectionSettings::Bond
-         || type == ConnectionSettings::Bridge
-         || type == ConnectionSettings::Vlan
-         || (type == ConnectionSettings::Vpn && serviceType == QLatin1String(NM_DBUS_SERVICE_OPENVPN))) && !isSlave()) {
+    if ((type == NetworkManager::ConnectionSettings::Wired
+         || type == NetworkManager::ConnectionSettings::Wireless
+         || type == NetworkManager::ConnectionSettings::Infiniband
+         || type == NetworkManager::ConnectionSettings::Wimax
+    #if NM_CHECK_VERSION(0, 9, 10)
+         || type == NetworkManager::ConnectionSettings::Team
+     #endif
+         || type == NetworkManager::ConnectionSettings::Bond
+         || type == NetworkManager::ConnectionSettings::Bridge
+         || type == NetworkManager::ConnectionSettings::Vlan) && !m_connection->isSlave()) {
         IPv6Widget * ipv6Widget = new IPv6Widget(m_connection->setting(NetworkManager::Setting::Ipv6), this);
         m_ui->tabWidget->addTab(ipv6Widget, i18n("IPv6"));
     }
@@ -412,15 +309,14 @@ void ConnectionDetailEditor::initTabs()
     KAcceleratorManager::manage(this);
 }
 
-void ConnectionDetailEditor::saveSetting()
+NMVariantMapMap ConnectionDetailEditor::setting()
 {
     ConnectionWidget * connectionWidget = static_cast<ConnectionWidget*>(m_ui->tabWidget->widget(0));
 
     NMVariantMapMap settings = connectionWidget->setting();
 
     bool agentOwned = false;
-    // We can store secrets into KWallet if KWallet is enabled and permissions list is not empty
-    if (!settings.value("connection").value("permissions").toStringList().isEmpty() && KWallet::Wallet::isEnabled()) {
+    if (!settings.value("connection").value("permissions").toStringList().isEmpty()) {
         agentOwned = true;
     }
 
@@ -452,14 +348,16 @@ void ConnectionDetailEditor::saveSetting()
         }
     }
 
-    NetworkManager::ConnectionSettings * connectionSettings = new NetworkManager::ConnectionSettings(m_connection->connectionType());
+    // Set properties which are not returned from setting widgets
+    NetworkManager::ConnectionSettings::Ptr connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(m_connection->connectionType()));
 
     connectionSettings->fromMap(settings);
     connectionSettings->setId(m_ui->connectionName->text());
+    connectionSettings->setUuid(m_connection->uuid());
 
-    if (connectionSettings->connectionType() == ConnectionSettings::Wireless) {
-        NetworkManager::WirelessSecuritySetting::Ptr securitySetting = connectionSettings->setting(Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
-        NetworkManager::WirelessSetting::Ptr wirelessSetting = connectionSettings->setting(Setting::Wireless).staticCast<NetworkManager::WirelessSetting>();
+    if (connectionSettings->connectionType() == NetworkManager::ConnectionSettings::Wireless) {
+        NetworkManager::WirelessSecuritySetting::Ptr securitySetting = connectionSettings->setting(NetworkManager::Setting::WirelessSecurity).staticCast<NetworkManager::WirelessSecuritySetting>();
+        NetworkManager::WirelessSetting::Ptr wirelessSetting = connectionSettings->setting(NetworkManager::Setting::Wireless).staticCast<NetworkManager::WirelessSetting>();
 
         if (securitySetting && wirelessSetting) {
             if (securitySetting->keyMgmt() != NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting::Unknown) {
@@ -468,59 +366,33 @@ void ConnectionDetailEditor::saveSetting()
         }
     }
 
-    // set UUID
-    connectionSettings->setUuid(m_connection->uuid());
-
-    // set master & slave type
-    if (isSlave()) {
-        connectionSettings->setMaster(m_masterUuid);
-        connectionSettings->setSlaveType(m_slaveType);
-    }
-
-    qDebug() << *connectionSettings;  // debug
-
-    if (m_new) { // create new connection
-        connect(NetworkManager::settingsNotifier(), SIGNAL(connectionAddComplete(QString,bool,QString)),
-                SLOT(connectionAddComplete(QString,bool,QString)));
-        NetworkManager::addConnection(connectionSettings->toMap());
-    } else {  // update existing connection
-        NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(connectionSettings->uuid());
-
-        if (connection) {
-            connection->update(connectionSettings->toMap());
-        }
-    }
+    return connectionSettings->toMap();
 }
 
-void ConnectionDetailEditor::connectionAddComplete(const QString& id, bool success, const QString& msg)
+void ConnectionDetailEditor::replyFinished(QDBusPendingCallWatcher *watcher)
 {
-    qDebug() << id << " - " << success << " - " << msg;
-}
-
-void ConnectionDetailEditor::gotSecrets(const QString& id, bool success, const NMVariantMapMap& secrets, const QString& msg)
-{
-    if (id == m_connection->uuid() && success) {
+    QDBusPendingReply<NMVariantMapMap> reply = *watcher;
+    if (reply.isValid()) {
+        NMVariantMapMap secrets = reply.argumentAt<0>();
         foreach (const QString & key, secrets.keys()) {
             NetworkManager::Setting::Ptr setting = m_connection->setting(NetworkManager::Setting::typeFromString(key));
-            if (setting) {
-                setting->secretsFromMap(secrets.value(key));
-            }
+            setting->secretsFromMap(secrets.value(key));
         }
+    } else {
+        KNotification *notification = new KNotification("FailedToGetSecrets", KNotification::CloseOnTimeout);
+        notification->setComponentName("networkmanagement");
+        notification->setTitle(i18n("Failed to get secrets for %1", watcher->property("connection").toString()));
+        notification->setText(reply.error().message());
+        notification->setPixmap(KIcon("dialog-warning").pixmap(64, 64));
+        notification->sendEvent();
+
+        connect(this, SIGNAL(accepted()), notification, SLOT(close()));
+        connect(this, SIGNAL(rejected()), notification, SLOT(close()));
     }
 
     initTabs();
 }
 
-void ConnectionDetailEditor::disconnectSignals()
-{
-    NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(m_connection->uuid());
-
-    if (connection) {
-        disconnect(connection.data(), SIGNAL(gotSecrets(QString,bool,NMVariantMapMap,QString)),
-                   this, SLOT(gotSecrets(QString,bool,NMVariantMapMap,QString)));
-    }
-}
-
 void ConnectionDetailEditor::validChanged(bool valid)
 {
     if (!valid) {
