@@ -23,6 +23,7 @@
 #include "connectiondetaileditor.h"
 
 #include <QDebug>
+#include <QDBusPendingReply>
 
 #include <NetworkManagerQt/GenericTypes>
 #include <NetworkManagerQt/Connection>
@@ -117,12 +118,21 @@ void BridgeWidget::addBridge(QAction *action)
     qDebug() << "Master UUID:" << m_uuid;
     qDebug() << "Slave type:" << type();
 
-    QPointer<ConnectionDetailEditor> bridgeEditor = new ConnectionDetailEditor(NetworkManager::ConnectionSettings::ConnectionType(action->data().toInt()),
-                                                                       this, m_uuid, type());
+    NetworkManager::ConnectionSettings::ConnectionType connectionType = static_cast<NetworkManager::ConnectionSettings::ConnectionType>(action->data().toInt());
+    NetworkManager::ConnectionSettings::Ptr connectionSettings = NetworkManager::ConnectionSettings::Ptr(new NetworkManager::ConnectionSettings(connectionType));
+    connectionSettings->setUuid(NetworkManager::ConnectionSettings::createNewUuid());
+    connectionSettings->setMaster(m_uuid);
+    connectionSettings->setSlaveType(type());
+    connectionSettings->setAutoconnect(false);
+
+    QPointer<ConnectionDetailEditor> bridgeEditor = new ConnectionDetailEditor(connectionSettings, true);
+
     if (bridgeEditor->exec() == QDialog::Accepted) {
         qDebug() << "Saving slave connection";
-        connect(NetworkManager::settingsNotifier(), SIGNAL(connectionAddComplete(QString,bool,QString)),
-                this, SLOT(bridgeAddComplete(QString,bool,QString)));
+        qDebug() << bridgeEditor->setting();
+        QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(bridgeEditor->setting());
+        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+        connect(watcher, &QDBusPendingCallWatcher::finished, this, &BridgeWidget::bridgeAddComplete);
     }
 
     if (bridgeEditor) {
@@ -138,23 +148,22 @@ void BridgeWidget::currentBridgeChanged(QListWidgetItem *current, QListWidgetIte
     m_ui->btnDelete->setEnabled(current);
 }
 
-void BridgeWidget::bridgeAddComplete(const QString &uuid, bool success, const QString &msg)
+void BridgeWidget::bridgeAddComplete(QDBusPendingCallWatcher * watcher)
 {
-    qDebug() << Q_FUNC_INFO << uuid << success << msg;
+    QDBusPendingReply<QDBusObjectPath> reply = *watcher;
 
-    // find the slave connection with matching UUID
-    NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(uuid);
-    if (connection && connection->settings()->master() == m_uuid && success) {
-        const QString label = QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
-        QListWidgetItem * slaveItem = new QListWidgetItem(label, m_ui->bridges);
-        slaveItem->setData(Qt::UserRole, uuid);
-        slotWidgetChanged();
+    if (reply.isValid()) {
+        // find the slave connection with matching UUID
+        NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(reply.value().path());
+        if (connection && connection->settings()->master() == m_uuid) {
+            const QString label = QString("%1 (%2)").arg(connection->name()).arg(connection->settings()->typeAsString(connection->settings()->connectionType()));
+            QListWidgetItem * slaveItem = new QListWidgetItem(label, m_ui->bridges);
+            slaveItem->setData(Qt::UserRole, connection->uuid());
+            slotWidgetChanged();
+        }
     } else {
-        qWarning() << "Bridged connection not added:" << msg;
+        qWarning() << "Bridged connection not added:" << reply.error().message();
     }
-
-    disconnect(NetworkManager::settingsNotifier(), SIGNAL(connectionAddComplete(QString,bool,QString)),
-               this, SLOT(bridgeAddComplete(QString,bool,QString)));
 }
 
 void BridgeWidget::editBridge()
@@ -170,6 +179,7 @@ void BridgeWidget::editBridge()
         qDebug() << "Editing bridged connection" << currentItem->text() << uuid;
         QPointer<ConnectionDetailEditor> bridgeEditor = new ConnectionDetailEditor(connection->settings(), this);
         if (bridgeEditor->exec() == QDialog::Accepted) {
+            connection->update(bridgeEditor->setting());
             connect(connection.data(), SIGNAL(updated()), this, SLOT(populateBridges()));
         }
 
