@@ -20,13 +20,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "ipv6routeswidget.h"
 
-#include <KLineEdit>
+#include <QDebug>
 #include <QStandardItem>
 #include <QStandardItemModel>
 #include <QNetworkAddressEntry>
 
-#include <KDebug>
 #include <KAcceleratorManager>
+#include <KLineEdit>
+#include <KLocalizedString>
 
 #include "ui_ipv6routes.h"
 
@@ -56,7 +57,7 @@ IpV6RoutesWidget::IpV6RoutesWidget(QWidget * parent)
 {
     d->ui.setupUi(this);
     d->ui.tableViewAddresses->setModel(&d->model);
-    d->ui.tableViewAddresses->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
+    d->ui.tableViewAddresses->horizontalHeader()->setResizeMode(QHeaderView::ResizeToContents);
 
     IpV6Delegate *ipDelegate = new IpV6Delegate(this);
     IntDelegate *netmaskDelegate = new IntDelegate(0,128,this);
@@ -115,7 +116,7 @@ void IpV6RoutesWidget::setRoutes(const QList<NetworkManager::IpRoute> &list)
     d->model.removeRows(0, d->model.rowCount());
     foreach (const NetworkManager::IpRoute &route, list) {
         QList<QStandardItem *> item;
-        kDebug() << route.ip();
+        qDebug() << route.ip();
         item << new QStandardItem(route.ip().toString())
              << new QStandardItem(QString::number(route.prefixLength(), 10))
              << new QStandardItem(route.nextHop().toString())
@@ -185,7 +186,7 @@ void IpV6RoutesWidget::removeRoute()
 
 void IpV6RoutesWidget::selectionChanged(const QItemSelection & selected)
 {
-    kDebug() << "selectionChanged";
+    qDebug() << "selectionChanged";
     d->ui.pushButtonRemove->setEnabled(!selected.isEmpty());
 }
 
