@@ -23,10 +23,9 @@
 #include "uiutils.h"
 
 #include <QVBoxLayout>
+#include <QDebug>
 
-#include <KLocale>
-#include <KDebug>
-#include <KGlobal>
+#include <KLocalizedString>
 #include <KIconLoader>
 #include <Solid/Device>
 
