@@ -1,5 +1,5 @@
 /*
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -36,16 +36,16 @@
 
 #include <QInputDialog>
 #include <QDBusError>
+#include <QIcon>
 
 #include <KNotification>
+#include <KLocalizedString>
 #include <KUser>
-#include <KIcon>
 #include <KDebug>
 #include <KProcess>
 #include <KService>
 #include <KServiceTypeTrader>
 #include <KWindowSystem>
-#include <KWallet/Wallet>
 
 Handler::Handler(QObject* parent)
     : QObject(parent)
@@ -53,12 +53,7 @@ Handler::Handler(QObject* parent)
     , m_tmpWimaxEnabled(NetworkManager::isWimaxEnabled())
     , m_tmpWirelessEnabled(NetworkManager::isWirelessEnabled())
     , m_tmpWwanEnabled(NetworkManager::isWwanEnabled())
-    , m_agentIface(QLatin1String("org.kde.kded"), QLatin1String("/modules/networkmanagement"),
-                   QLatin1String("org.kde.plasmanetworkmanagement"))
 {
-    initKdedModule();
-    QDBusConnection::sessionBus().connect(m_agentIface.service(), m_agentIface.path(), m_agentIface.interface(), QLatin1String("registered"),
-                                          this, SLOT(initKdedModule()));
 }
 
 Handler::~Handler()
@@ -84,10 +79,10 @@ void Handler::activateConnection(const QString& connection, const QString& devic
             if (services.isEmpty()) {
                 kWarning() << "VPN" << vpnSetting->serviceType() << "not found, skipping";
                 KNotification *notification = new KNotification("MissingVpnPlugin", KNotification::CloseOnTimeout, this);
-                notification->setComponentData(KComponentData("networkmanagement"));
+                notification->setComponentName("networkmanagement");
                 notification->setTitle(con->name());
                 notification->setText(i18n("Missing VPN plugin"));
-                notification->setPixmap(KIcon("dialog-warning").pixmap(64, 64));
+                notification->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(64, 64));
                 notification->sendEvent();
                 return;
             }
@@ -157,18 +152,23 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
         m_tmpDevicePath = device;
         m_tmpSpecificPath = specificObject;
 
-        QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(settings, 0, 0, true);
+        QPointer<ConnectionDetailEditor> editor = new ConnectionDetailEditor(settings, true);
         editor->show();
         KWindowSystem::setState(editor->winId(), NET::KeepAbove);
         KWindowSystem::forceActiveWindow(editor->winId());
-        connect(editor, SIGNAL(accepted()), SLOT(editDialogAccepted()));
+
+        if (editor->exec() == QDialog::Accepted) {
+            addConnection(editor->setting());
+        }
+
+        if (editor) {
+            editor->deleteLater();
+        }
     } else {
         if (securityType == NetworkManager::Utils::StaticWep) {
             wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::Wep);
             wifiSecurity->setWepKey0(password);
-            if (KWallet::Wallet::isEnabled()) {
-                wifiSecurity->setWepKeyFlags(NetworkManager::Setting::AgentOwned);
-            }
+            wifiSecurity->setWepKeyFlags(NetworkManager::Setting::AgentOwned);
         } else {
             if (ap->mode() == NetworkManager::AccessPoint::Adhoc) {
                 wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::WpaNone);
@@ -176,9 +176,7 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
                 wifiSecurity->setKeyMgmt(NetworkManager::WirelessSecuritySetting::WpaPsk);
             }
             wifiSecurity->setPsk(password);
-            if (KWallet::Wallet::isEnabled()) {
-                wifiSecurity->setPskFlags(NetworkManager::Setting::AgentOwned);
-            }
+            wifiSecurity->setPskFlags(NetworkManager::Setting::AgentOwned);
         }
         QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addAndActivateConnection(settings->toMap(), device, specificObject);
         QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
@@ -190,6 +188,15 @@ void Handler::addAndActivateConnection(const QString& device, const QString& spe
     settings.clear();
 }
 
+void Handler::addConnection(const NMVariantMapMap& map)
+{
+    QDBusPendingReply<QDBusObjectPath> reply = NetworkManager::addConnection(map);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    watcher->setProperty("action", AddConnection);
+    watcher->setProperty("connection", map.value("connection").value("id"));
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
+}
+
 void Handler::deactivateConnection(const QString& connection, const QString& device)
 {
     NetworkManager::Connection::Ptr con = NetworkManager::findConnection(connection);
@@ -199,22 +206,27 @@ void Handler::deactivateConnection(const QString& connection, const QString& dev
         return;
     }
 
+    QDBusPendingReply<> reply;
     foreach (const NetworkManager::ActiveConnection::Ptr & active, NetworkManager::activeConnections()) {
         if (active->uuid() == con->uuid() && ((!active->devices().isEmpty() && active->devices().first() == device) ||
                                                active->vpn())) {
             if (active->vpn()) {
-                NetworkManager::deactivateConnection(active->path());
+                reply = NetworkManager::deactivateConnection(active->path());
             } else {
                 if (active->devices().isEmpty()) {
-                    NetworkManager::deactivateConnection(connection);
+                    reply = NetworkManager::deactivateConnection(connection);
                 }
                 NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(active->devices().first());
                 if (device) {
-                    device->disconnectInterface();
+                    reply = device->disconnectInterface();
                 }
             }
         }
     }
+
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    watcher->setProperty("action", Handler::DeactivateConnection);
+    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(replyFinished(QDBusPendingCallWatcher*)));
 }
 
 void Handler::disconnectAll()
@@ -273,7 +285,6 @@ void Handler::enableWwan(bool enable)
 
 bool Handler::isBtEnabled()
 {
-    qDBusRegisterMetaType< QMap<QDBusObjectPath, NMVariantMapMap > >();
     bool result = false;
 
     QDBusInterface managerIface("org.bluez", "/", "org.freedesktop.DBus.ObjectManager", QDBusConnection::systemBus(), this);
@@ -319,12 +330,12 @@ void Handler::enableBt(bool enable)
     }
 }
 
-void Handler::editConnection(const QString& uuid)
-{
-    QStringList args;
-    args << uuid;
-    KProcess::startDetached("kde-nm-connection-editor", args);
-}
+// void Handler::editConnection(const QString& uuid)
+// {
+//     QStringList args;
+//     args << uuid;
+//     KProcess::startDetached("kde5-nm-connection-editor", args);
+// }
 
 void Handler::removeConnection(const QString& connection)
 {
@@ -335,19 +346,33 @@ void Handler::removeConnection(const QString& connection)
         return;
     }
 
-    foreach (const NetworkManager::Connection::Ptr &masterConnection, NetworkManager::listConnections()) {
-        NetworkManager::ConnectionSettings::Ptr settings = masterConnection->settings();
+    // Remove slave connections
+    foreach (const NetworkManager::Connection::Ptr &connection, NetworkManager::listConnections()) {
+        NetworkManager::ConnectionSettings::Ptr settings = connection->settings();
         if (settings->master() == con->uuid()) {
-            masterConnection->remove();
+            connection->remove();
         }
     }
 
-    con->remove();
+    QDBusPendingReply<> reply = con->remove();
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    watcher->setProperty("action", Handler::RemoveConnection);
+    watcher->setProperty("connection", con->name());
+    connect(watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), this, SLOT(replyFinished(QDBusPendingCallWatcher*)));
+}
+
+void Handler::updateConnection(const NetworkManager::Connection::Ptr& connection, const NMVariantMapMap& map)
+{
+    QDBusPendingReply<> reply = connection->update(map);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(reply, this);
+    watcher->setProperty("action", UpdateConnection);
+    watcher->setProperty("connection", connection->name());
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, &Handler::replyFinished);
 }
 
 void Handler::openEditor()
 {
-    KProcess::startDetached("kde-nm-connection-editor");
+    KProcess::startDetached("kde5-nm-connection-editor");
 }
 
 void Handler::requestScan()
@@ -365,19 +390,6 @@ void Handler::requestScan()
     }
 }
 
-void Handler::editDialogAccepted()
-{
-    NetworkManager::Connection::Ptr newConnection = NetworkManager::findConnectionByUuid(m_tmpConnectionUuid);
-    if (newConnection) {
-        activateConnection(newConnection->path(), m_tmpDevicePath, m_tmpSpecificPath);
-    }
-}
-
-void Handler::initKdedModule()
-{
-    m_agentIface.call(QLatin1String("init"));
-}
-
 void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
 {
     QDBusPendingReply<> reply = *watcher;
@@ -388,26 +400,77 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
         switch (action) {
             case Handler::ActivateConnection:
                 notification = new KNotification("FailedToActivateConnection", KNotification::CloseOnTimeout, this);
-                notification->setComponentData(KComponentData("networkmanagement"));
+                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to activate %1", watcher->property("connection").toString()));
                 break;
             case Handler::AddAndActivateConnection:
                 notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
-                notification->setComponentData(KComponentData("networkmanagement"));
+                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to add %1", watcher->property("connection").toString()));
                 break;
+            case Handler::AddConnection:
+                notification = new KNotification("FailedToAddConnection", KNotification::CloseOnTimeout, this);
+                notification->setComponentName("networkmanagement");
+                notification->setTitle(i18n("Failed to add connection %1", watcher->property("connection").toString()));
+                break;
+            case Handler::DeactivateConnection:
+                notification = new KNotification("FailedToDeactivateConnection", KNotification::CloseOnTimeout, this);
+                notification->setComponentName("networkmanagement");
+                notification->setTitle(i18n("Failed to deactivate %1", watcher->property("connection").toString()));
+                break;
+            case Handler::RemoveConnection:
+                notification = new KNotification("FailedToRemoveConnection", KNotification::CloseOnTimeout, this);
+                notification->setComponentName("networkmanagement");
+                notification->setTitle(i18n("Failed to remove %1", watcher->property("connection").toString()));
+                break;
             case Handler::RequestScan:
                 notification = new KNotification("FailedToRequestScan", KNotification::CloseOnTimeout, this);
-                notification->setComponentData(KComponentData("networkmanagement"));
+                notification->setComponentName("networkmanagement");
                 notification->setTitle(i18n("Failed to request scan"));
                 break;
+            case Handler::UpdateConnection:
+                notification = new KNotification("FailedToUpdateConnection", KNotification::CloseOnTimeout, this);
+                notification->setComponentName("networkmanagement");
+                notification->setTitle(i18n("Failed to update connection %1", watcher->property("connection").toString()));
+                break;
             default:
                 break;
         }
 
         if (notification) {
             notification->setText(error);
-            notification->setPixmap(KIcon("dialog-warning").pixmap(64, 64));
+            notification->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(64, 64));
+            notification->sendEvent();
+        }
+    } else {
+        KNotification *notification = 0;
+        Handler::HandlerAction action = (Handler::HandlerAction)watcher->property("action").toUInt();
+
+        switch (action) {
+            case Handler::AddConnection:
+                notification = new KNotification("ConnectionAdded", KNotification::CloseOnTimeout, this);
+                notification->setComponentName("networkmanagement");
+                notification->setTitle(watcher->property("connection").toString());
+                notification->setText(i18n("Connection %1 has been added", watcher->property("connection").toString()));
+                break;
+            case Handler::RemoveConnection:
+                notification = new KNotification("ConnectionRemoved", KNotification::CloseOnTimeout, this);
+                notification->setComponentName("networkmanagement");
+                notification->setTitle(watcher->property("connection").toString());
+                notification->setText(i18n("Connection %1 has been removed", watcher->property("connection").toString()));
+                break;
+            case Handler::UpdateConnection:
+                notification = new KNotification("ConnectionUpdated", KNotification::CloseOnTimeout, this);
+                notification->setComponentName("networkmanagement");
+                notification->setTitle(watcher->property("connection").toString());
+                notification->setText(i18n("Connection %1 has been updated", watcher->property("connection").toString()));
+                break;
+            default:
+                break;
+        }
+
+        if (notification) {
+            notification->setPixmap(QIcon::fromTheme("dialog-information").pixmap(64, 64));
             notification->sendEvent();
         }
     }
