@@ -1,5 +1,5 @@
 /*
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -21,17 +21,11 @@
 #ifndef PLASMA_NM_HANDLER_H
 #define PLASMA_NM_HANDLER_H
 
-#include <QDBusInterface>
-
 #include <NetworkManagerQt/Connection>
 
 #include "plasmanm_export.h"
 #include <config.h>
 
-#if !WITH_MODEMMANAGER_SUPPORT
-typedef QMap<QDBusObjectPath, NMVariantMapMap> NMDBusObjectVariantMapMap;
-Q_DECLARE_METATYPE(NMDBusObjectVariantMapMap)
-#endif
 
 class PLASMA_NM_EXPORT Handler : public QObject
 {
@@ -41,7 +35,11 @@ public:
     enum HandlerAction {
         ActivateConnection,
         AddAndActivateConnection,
-        RequestScan
+        AddConnection,
+        DeactivateConnection,
+        RemoveConnection,
+        RequestScan,
+        UpdateConnection
     };
 
     explicit Handler(QObject* parent = 0);
@@ -54,7 +52,7 @@ public Q_SLOTS:
      * @device - d-bus path of the device where the connection should be activated
      * @specificParameter - d-bus path of the specific object you want to use for this activation, i.e access point
      */
-    void activateConnection(const QString & connection, const QString & device, const QString & specificParameter);
+    void activateConnection(const QString &connection, const QString &device, const QString &specificParameter);
     /**
      * Adds and activates a new wireless connection
      * @device - d-bus path of the wireless device where the connection should be activated
@@ -65,13 +63,18 @@ public Q_SLOTS:
      * Works automatically for wireless connections with WEP/WPA security, for wireless connections with WPA/WPA
      * it will open the connection editor for advanced configuration.
      * */
-    void addAndActivateConnection(const QString & device, const QString & specificParameter, const QString & password = QString());
+    void addAndActivateConnection(const QString &device, const QString &specificParameter, const QString &password = QString());
+    /**
+     * Adds a new connection
+     * @map - NMVariantMapMap with connection settings
+     */
+    void addConnection(const NMVariantMapMap &map);
     /**
      * Deactivates given connection
      * @connection - d-bus path of the connection you want to deactivate
      * @device - d-bus path of the connection where the connection is activated
      */
-    void deactivateConnection(const QString & connection, const QString & device);
+    void deactivateConnection(const QString &connection, const QString &device);
     /**
      * Disconnects all connections
      */
@@ -82,24 +85,26 @@ public Q_SLOTS:
     void enableWireless(bool enable);
     void enableWimax(bool enable);
     void enableWwan(bool enable);
-
-    /**
-     * Opens connection editor for given connection
-     * @uuid - uuid of the connection you want to edit
-     */
-    void editConnection(const QString & uuid);
-
+//     /**
+//      * Opens connection editor for given connection
+//      * @uuid - uuid of the connection you want to edit
+//      */
+//     void editConnection(const QString & uuid);
     /**
      * Removes given connection
      * @connection - d-bus path of the connection you want to edit
      */
     void removeConnection(const QString & connection);
+    /**
+     * Updates given connection
+     * @connection - connection which should be updated
+     * @map - NMVariantMapMap with new connection settings
+     */
+    void updateConnection(const NetworkManager::Connection::Ptr &connection, const NMVariantMapMap &map);
     void openEditor();
     void requestScan();
 
 private Q_SLOTS:
-    void editDialogAccepted();
-    void initKdedModule();
     void replyFinished(QDBusPendingCallWatcher * watcher);
 
 private:
@@ -112,7 +117,6 @@ private:
     QString m_tmpSpecificPath;
 
     bool isBtEnabled();
-    QDBusInterface m_agentIface;
 };
 
 #endif // PLASMA_NM_HANDLER_H
