@@ -1,5 +1,5 @@
 /*
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -54,6 +54,11 @@ AppletProxyModel::SortedConnectionType AppletProxyModel::connectionTypeToSortedT
         case NetworkManager::ConnectionSettings::Pppoe:
             return AppletProxyModel::Pppoe;
             break;
+#if NM_CHECK_VERSION(0, 9, 10)
+        case NetworkManager::ConnectionSettings::Team:
+            return AppletProxyModel::Team;
+            break;
+#endif
         case NetworkManager::ConnectionSettings::Vlan:
             return AppletProxyModel::Vlan;
             break;
@@ -96,13 +101,6 @@ bool AppletProxyModel::filterAcceptsRow(int source_row, const QModelIndex& sourc
         return false;
     }
 
-#if NM_CHECK_VERSION(0, 9, 10)
-    const NetworkManager::ConnectionSettings::ConnectionType type = (NetworkManager::ConnectionSettings::ConnectionType) sourceModel()->data(index, NetworkModel::TypeRole).toUInt();
-    if (type < NetworkManager::ConnectionSettings::Adsl || type > NetworkManager::ConnectionSettings::Wireless) {
-        return false;
-    }
-#endif
-
     NetworkModelItem::ItemType itemType = (NetworkModelItem::ItemType)sourceModel()->data(index, NetworkModel::ItemTypeRole).toUInt();
 
     if (itemType == NetworkModelItem::AvailableConnection ||
@@ -118,21 +116,17 @@ bool AppletProxyModel::lessThan(const QModelIndex& left, const QModelIndex& righ
 {
     const bool leftAvailable = (NetworkModelItem::ItemType)sourceModel()->data(left, NetworkModel::ItemTypeRole).toUInt() != NetworkModelItem::UnavailableConnection;
     const bool leftConnected = sourceModel()->data(left, NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
-    const int leftConnectionState = sourceModel()->data(left, NetworkModel::ConnectionStateRole).toUInt();
     const QString leftName = sourceModel()->data(left, NetworkModel::NameRole).toString();
     const SortedConnectionType leftType = connectionTypeToSortedType((NetworkManager::ConnectionSettings::ConnectionType) sourceModel()->data(left, NetworkModel::TypeRole).toUInt());
     const QString leftUuid = sourceModel()->data(left, NetworkModel::UuidRole).toString();
     const int leftSignal = sourceModel()->data(left, NetworkModel::SignalRole).toInt();
-    const QDateTime leftDate = sourceModel()->data(left, NetworkModel::TimeStampRole).toDateTime();
 
     const bool rightAvailable = (NetworkModelItem::ItemType)sourceModel()->data(right, NetworkModel::ItemTypeRole).toUInt() != NetworkModelItem::UnavailableConnection;
     const bool rightConnected = sourceModel()->data(right, NetworkModel::ConnectionStateRole).toUInt() == NetworkManager::ActiveConnection::Activated;
-    const int rightConnectionState = sourceModel()->data(right, NetworkModel::ConnectionStateRole).toUInt();
     const QString rightName = sourceModel()->data(right, NetworkModel::NameRole).toString();
     const SortedConnectionType rightType = connectionTypeToSortedType((NetworkManager::ConnectionSettings::ConnectionType) sourceModel()->data(right, NetworkModel::TypeRole).toUInt());
     const QString rightUuid = sourceModel()->data(right, NetworkModel::UuidRole).toString();
     const int rightSignal = sourceModel()->data(right, NetworkModel::SignalRole).toInt();
-    const QDateTime rightDate = sourceModel()->data(right, NetworkModel::TimeStampRole).toDateTime();
 
     if (leftAvailable < rightAvailable) {
         return true;
@@ -146,12 +140,6 @@ bool AppletProxyModel::lessThan(const QModelIndex& left, const QModelIndex& righ
         return false;
     }
 
-    if (leftConnectionState > rightConnectionState) {
-        return true;
-    } else if (leftConnectionState < rightConnectionState) {
-        return false;
-    }
-
     if (leftUuid.isEmpty() && !rightUuid.isEmpty()) {
         return true;
     } else if (!leftUuid.isEmpty() && rightUuid.isEmpty()) {
@@ -164,12 +152,6 @@ bool AppletProxyModel::lessThan(const QModelIndex& left, const QModelIndex& righ
         return true;
     }
 
-    if (leftDate > rightDate) {
-        return false;
-    } else if (leftDate < rightDate) {
-        return true;
-    }
-
     if (leftSignal < rightSignal) {
         return true;
     } else if (leftSignal > rightSignal) {
