@@ -30,7 +30,25 @@ class PLASMA_NM_EXPORT AppletProxyModel : public QSortFilterProxyModel
 Q_OBJECT
 Q_PROPERTY(QAbstractItemModel * sourceModel READ sourceModel WRITE setSourceModel)
 public:
-    enum SortedConnectionType {Wired, Wireless, Wimax, Gsm, Cdma, Pppoe, Adsl, Infiniband, OLPCMesh, Bluetooth, Vpn, Vlan, Bridge, Bond, Unknown };
+    enum SortedConnectionType {
+        Wired,
+        Wireless,
+        Wimax,
+        Gsm,
+        Cdma,
+        Pppoe,
+        Adsl,
+        Infiniband,
+        OLPCMesh,
+        Bluetooth,
+        Vpn,
+        Vlan,
+        Bridge,
+        Bond,
+#if NM_CHECK_VERSION(0, 9, 10)
+        Team,
+#endif
+        Unknown };
 
     static SortedConnectionType connectionTypeToSortedType(NetworkManager::ConnectionSettings::ConnectionType type);
 
