@@ -1,5 +1,5 @@
 /*
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
+    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -47,13 +47,6 @@ bool EditorProxyModel::filterAcceptsRow(int source_row, const QModelIndex& sourc
         return false;
     }
 
-#if NM_CHECK_VERSION(0, 9, 10)
-    const NetworkManager::ConnectionSettings::ConnectionType type = (NetworkManager::ConnectionSettings::ConnectionType) sourceModel()->data(index, NetworkModel::TypeRole).toUInt();
-    if (type < NetworkManager::ConnectionSettings::Adsl || type > NetworkManager::ConnectionSettings::Wireless) {
-        return false;
-    }
-#endif
-
     NetworkModelItem::ItemType itemType = (NetworkModelItem::ItemType)sourceModel()->data(index, NetworkModel::ItemTypeRole).toUInt();
     if (itemType == NetworkModelItem::AvailableAccessPoint || itemType == NetworkModelItem::AvailableNsp) {
         return false;
