@@ -19,14 +19,21 @@
 */
 
 #include "networkmodelitem.h"
-#include "globalconfig.h"
 #include "uiutils.h"
 
+#include <NetworkManagerQt/AdslDevice>
 #include <NetworkManagerQt/BluetoothDevice>
+#include <NetworkManagerQt/BondDevice>
+#include <NetworkManagerQt/BridgeDevice>
+#include <NetworkManagerQt/InfinibandDevice>
 #include <NetworkManagerQt/Manager>
 #include <NetworkManagerQt/ModemDevice>
 #include <NetworkManagerQt/Settings>
+#if NM_CHECK_VERSION (0, 9, 10)
+#include <NetworkManagerQt/TeamDevice>
+#endif
 #include <NetworkManagerQt/Utils>
+#include <NetworkManagerQt/VlanDevice>
 #include <NetworkManagerQt/VpnConnection>
 #include <NetworkManagerQt/VpnSetting>
 #include <NetworkManagerQt/WimaxDevice>
@@ -34,15 +41,15 @@
 #include <NetworkManagerQt/WirelessDevice>
 #include <NetworkManagerQt/WirelessSetting>
 
-#include <KGlobal>
 #include <KLocale>
 #include <KLocalizedString>
 
-#include <Plasma/DataEngineManager>
-
 #if WITH_MODEMMANAGER_SUPPORT
 #include <ModemManagerQt/manager.h>
 #include <ModemManagerQt/modem.h>
+#include <ModemManagerQt/modemdevice.h>
+#include <ModemManagerQt/modem3gpp.h>
+#include <ModemManagerQt/modemcdma.h>
 #endif
 
 NetworkModelItem::NetworkModelItem(QObject* parent)
@@ -50,11 +57,14 @@ NetworkModelItem::NetworkModelItem(QObject* parent)
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
     , m_deviceState(NetworkManager::Device::UnknownState)
     , m_duplicate(false)
+    , m_engine(0)
+    , m_dataEngineConsumer(new Plasma::DataEngineConsumer)
     , m_mode(NetworkManager::WirelessSetting::Infrastructure)
     , m_securityType(NetworkManager::Utils::None)
     , m_signal(0)
     , m_slave(false)
     , m_type(NetworkManager::ConnectionSettings::Unknown)
+    , m_updateEnabled(false)
     , m_vpnState(NetworkManager::VpnConnection::Unknown)
 {
 }
@@ -64,6 +74,7 @@ NetworkModelItem::NetworkModelItem(const NetworkModelItem* item, QObject* parent
     , m_connectionPath(item->connectionPath())
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
     , m_duplicate(true)
+    , m_engine(0)
     , m_mode(item->mode())
     , m_name(item->name())
     , m_securityType(item->securityType())
@@ -108,9 +119,15 @@ NetworkManager::ActiveConnection::State NetworkModelItem::connectionState() cons
 void NetworkModelItem::setConnectionState(NetworkManager::ActiveConnection::State state)
 {
     m_connectionState = state;
+
+    if (m_connectionState == NetworkManager::ActiveConnection::Activated && !m_devicePath.isEmpty()) {
+        initializeDataEngine();
+    } else {
+        removeDataEngine();
+    }
 }
 
-QString NetworkModelItem::details() const
+QStringList NetworkModelItem::details() const
 {
     return m_details;
 }
@@ -120,11 +137,6 @@ QString NetworkModelItem::devicePath() const
     return m_devicePath;
 }
 
-QString NetworkModelItem::deviceName() const
-{
-    return m_deviceName;
-}
-
 void NetworkModelItem::setDeviceName(const QString& name)
 {
     m_deviceName = name;
@@ -145,6 +157,12 @@ void NetworkModelItem::setDeviceState(const NetworkManager::Device::State state)
     m_deviceState = state;
 }
 
+QString NetworkModelItem::download() const
+{
+    double download = m_download.toDouble();
+    return KLocale::global()->formatByteSize(download*1024) + "/s";
+}
+
 bool NetworkModelItem::duplicate() const
 {
     return m_duplicate;
@@ -220,19 +238,19 @@ QString NetworkModelItem::icon() const
         case NetworkManager::ConnectionSettings::Wireless:
             if (m_signal == 0 ) {
                 if (m_mode == NetworkManager::WirelessSetting::Adhoc || m_mode == NetworkManager::WirelessSetting::Ap) {
-                    return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-100" : "network-wireless-100-locked";
+                    return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-100" : "network-wireless-100-locked";
                 }
-                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-0" : "network-wireless-0-locked";
+                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-0" : "network-wireless-0-locked";
             } else if (m_signal < 20) {
-                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-20" : "network-wireless-20-locked";
+                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-20" : "network-wireless-20-locked";
             } else if (m_signal < 40) {
-                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-40" : "network-wireless-40-locked";
+                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-40" : "network-wireless-40-locked";
             } else if (m_signal < 60) {
-                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-60" : "network-wireless-60-locked";
+                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-60" : "network-wireless-60-locked";
             } else if (m_signal < 80) {
-                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-80" : "network-wireless-80-locked";
+                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-80" : "network-wireless-80-locked";
             } else {
-                return (m_securityType <= NetworkManager::Utils::None) ? "network-wireless-100" : "network-wireless-100-locked";
+                return (m_securityType == NetworkManager::Utils::None) ? "network-wireless-100" : "network-wireless-100-locked";
             }
             break;
         default:
@@ -252,6 +270,9 @@ NetworkModelItem::ItemType NetworkModelItem::itemType() const
         m_type == NetworkManager::ConnectionSettings::Bond ||
         m_type == NetworkManager::ConnectionSettings::Bridge ||
         m_type == NetworkManager::ConnectionSettings::Vlan ||
+#if NM_CHECK_VERSION(0, 9, 10)
+        m_type == NetworkManager::ConnectionSettings::Team ||
+#endif
         ((NetworkManager::status() == NetworkManager::Connected ||
           NetworkManager::status() == NetworkManager::ConnectedLinkLocal ||
           NetworkManager::status() == NetworkManager::ConnectedSiteOnly) && m_type == NetworkManager::ConnectionSettings::Vpn)) {
@@ -394,6 +415,12 @@ QString NetworkModelItem::uni() const
     }
 }
 
+QString NetworkModelItem::upload() const
+{
+    double upload = m_upload.toDouble();
+    return KLocale::global()->formatByteSize(upload*1024) + "/s";
+}
+
 QString NetworkModelItem::uuid() const
 {
     return m_uuid;
@@ -435,54 +462,76 @@ bool NetworkModelItem::operator==(const NetworkModelItem* item) const
 
 void NetworkModelItem::updateDetails()
 {
+    m_details.clear();
+
     if (itemType() == NetworkModelItem::UnavailableConnection) {
         return;
     }
 
-    m_details = "<qt><table>";
-
-    QStringList detailsList = GlobalConfig().detailKeys();
-
-    NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(m_connectionPath);
     NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(m_devicePath);
 
-    m_details += UiUtils::connectionDetails(device, connection, detailsList);
+    // Get IPv[46]Address
+    if (device && device->ipV4Config().isValid() && m_connectionState == NetworkManager::ActiveConnection::Activated) {
+        if (!device->ipV4Config().addresses().isEmpty()) {
+            QHostAddress addr = device->ipV4Config().addresses().first().ip();
+            if (!addr.isNull()) {
+                m_details << i18n("IPv4 Address") << addr.toString();
+            }
+        }
+    }
 
-    if (m_type == NetworkManager::ConnectionSettings::Bluetooth) {
-        NetworkManager::BluetoothDevice::Ptr btDevice = device.objectCast<NetworkManager::BluetoothDevice>();
-        m_details += UiUtils::bluetoothDetails(btDevice, detailsList);
-    } else if (m_type == NetworkManager::ConnectionSettings::Gsm || m_type == NetworkManager::ConnectionSettings::Cdma) {
-        NetworkManager::ModemDevice::Ptr modemDevice = device.objectCast<NetworkManager::ModemDevice>();
-        m_details += UiUtils::modemDetails(modemDevice, detailsList);
-    } else if (m_type == NetworkManager::ConnectionSettings::Wimax) {
-        NetworkManager::WimaxNsp::Ptr wimaxNsp;
-        NetworkManager::WimaxDevice::Ptr wimaxDevice = device.objectCast<NetworkManager::WimaxDevice>();
-        wimaxNsp = wimaxDevice->findNsp(m_specificPath);
-        if (wimaxDevice && wimaxNsp) {
-            m_details += UiUtils::wimaxDetails(wimaxDevice, wimaxNsp, connection, detailsList);
+    if (device && device->ipV6Config().isValid() && m_connectionState == NetworkManager::ActiveConnection::Activated) {
+        if (!device->ipV6Config().addresses().isEmpty()) {
+            QHostAddress addr = device->ipV6Config().addresses().first().ip();
+            if (!addr.isNull()) {
+                m_details << i18n("IPv6 Address") << addr.toString();
+            }
         }
-    } else if (m_type == NetworkManager::ConnectionSettings::Wired) {
-        NetworkManager::WiredDevice::Ptr wiredDevice;
-        if (device) {
-            wiredDevice = device.objectCast<NetworkManager::WiredDevice>();
+    }
+
+    if (m_type == NetworkManager::ConnectionSettings::Wired) {
+        NetworkManager::WiredDevice::Ptr wiredDevice = device.objectCast<NetworkManager::WiredDevice>();
+        if (wiredDevice) {
+            if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
+                m_details << i18n("Connection speed") << UiUtils::connectionSpeed(wiredDevice->bitRate());
+            }
+            m_details << i18n("MAC Address") << wiredDevice->permanentHardwareAddress();
         }
-        m_details += UiUtils::wiredDetails(wiredDevice, connection, detailsList);
     } else if (m_type == NetworkManager::ConnectionSettings::Wireless) {
-        NetworkManager::WirelessDevice::Ptr wirelessDevice;
-        if (device) {
-            wirelessDevice = device.objectCast<NetworkManager::WirelessDevice>();
+        NetworkManager::WirelessDevice::Ptr wirelessDevice = device.objectCast<NetworkManager::WirelessDevice>();
+        m_details << i18n("Access point (SSID)") << m_ssid;
+        if (m_mode == NetworkManager::WirelessSetting::Infrastructure) {
+            m_details << i18n("Signal strength") << QString("%1%").arg(m_signal);
+        }
+        if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
+            m_details << i18n("Security type") << UiUtils::labelFromWirelessSecurity(m_securityType);
         }
-        NetworkManager::AccessPoint::Ptr ap;
         if (wirelessDevice) {
-            ap = wirelessDevice->findAccessPoint(m_specificPath);
+            if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
+                m_details << i18n("Connection speed") << UiUtils::connectionSpeed(wirelessDevice->bitRate());
+            }
+            m_details << i18n("MAC Address") << wirelessDevice->permanentHardwareAddress();
         }
-        m_details += UiUtils::wirelessDetails(wirelessDevice, ap, connection, detailsList);
+    } else if (m_type == NetworkManager::ConnectionSettings::Gsm || m_type == NetworkManager::ConnectionSettings::Cdma) {
+#if WITH_MODEMMANAGER_SUPPORT
+        NetworkManager::ModemDevice::Ptr modemDevice = device.objectCast<NetworkManager::ModemDevice>();
+        ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(modemDevice->udi());
+        ModemManager::Modem::Ptr modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
+
+        if (m_type == NetworkManager::ConnectionSettings::Gsm) {
+            ModemManager::Modem3gpp::Ptr gsmNet = modem->interface(ModemManager::ModemDevice::GsmInterface).objectCast<ModemManager::Modem3gpp>();
+            m_details << i18n("Operator") << gsmNet->operatorName();
+        } else {
+            ModemManager::ModemCdma::Ptr cdmaNet = modem->interface(ModemManager::ModemDevice::CdmaInterface).objectCast<ModemManager::ModemCdma>();
+            m_details << i18n("Network ID") << QString("%1%").arg(cdmaNet->nid());
+        }
+        m_details << i18n("Signal Quality") << QString("%1%").arg(modemNetwork->signalQuality().signal);
+        m_details << i18n("Access Technology") << UiUtils::convertAccessTechnologyToString(modemNetwork->accessTechnologies());
+#endif
     } else if (m_type == NetworkManager::ConnectionSettings::Vpn) {
-        NetworkManager::ActiveConnection::Ptr active = NetworkManager::findActiveConnection(m_activeConnectionPath);
         NetworkManager::Connection::Ptr connection = NetworkManager::findConnection(m_connectionPath);
         NetworkManager::ConnectionSettings::Ptr connectionSettings;
         NetworkManager::VpnSetting::Ptr vpnSetting;
-        NetworkManager::VpnConnection::Ptr vpnConnection;
 
         if (connection) {
             connectionSettings = connection->settings();
@@ -491,11 +540,136 @@ void NetworkModelItem::updateDetails()
             vpnSetting = connectionSettings->setting(NetworkManager::Setting::Vpn).dynamicCast<NetworkManager::VpnSetting>();
         }
 
-        if (active) {
-            vpnConnection = NetworkManager::VpnConnection::Ptr(new NetworkManager::VpnConnection(active->path()), &QObject::deleteLater);
+        if (vpnSetting) {
+            m_details << i18n("VPN plugin") << vpnSetting->serviceType().section('.', -1);
         }
-        m_details += UiUtils::vpnDetails(vpnConnection, vpnSetting, detailsList);
+
+        if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
+            NetworkManager::ActiveConnection::Ptr active = NetworkManager::findActiveConnection(m_activeConnectionPath);
+            NetworkManager::VpnConnection::Ptr vpnConnection;
+
+            if (active) {
+                vpnConnection = NetworkManager::VpnConnection::Ptr(new NetworkManager::VpnConnection(active->path()), &QObject::deleteLater);
+            }
+
+            if (vpnConnection) {
+                m_details << i18n("Banner") << vpnConnection->banner().simplified();
+            }
+        }
+    } else if (m_type == NetworkManager::ConnectionSettings::Bluetooth) {
+        NetworkManager::BluetoothDevice::Ptr bluetoothDevice = device.objectCast<NetworkManager::BluetoothDevice>();
+        if (bluetoothDevice) {
+            m_details << i18n("Name") << bluetoothDevice->name();
+            if (bluetoothDevice->bluetoothCapabilities() == NetworkManager::BluetoothDevice::Pan) {
+                m_details << i18n("Capabilities") << "PAN";
+            } else if (bluetoothDevice->bluetoothCapabilities() == NetworkManager::BluetoothDevice::Dun) {
+                m_details << i18n("Capabilities") << "DUN";
+            }
+            m_details << i18n("MAC Address") << bluetoothDevice->hardwareAddress();
+
+        }
+    } else if (m_type == NetworkManager::ConnectionSettings::Wimax) {
+        NetworkManager::WimaxDevice::Ptr wimaxDevice = device.objectCast<NetworkManager::WimaxDevice>();
+        if (wimaxDevice) {
+            NetworkManager::WimaxNsp::Ptr wimaxNsp = wimaxDevice->findNsp(m_specificPath);
+            m_details << i18n("NSP Name") << m_nsp;
+            m_details << i18n("Signal Strength") << QString("%1%").arg(m_signal);
+            if (wimaxNsp) {
+                m_details << i18n("Network Type");
+            }
+            m_details << i18n("Bsid") << wimaxDevice->bsid();
+            m_details << i18n("MAC Address") << wimaxDevice->hardwareAddress();
+        }
+    } else if (m_type == NetworkManager::ConnectionSettings::Infiniband) {
+        NetworkManager::InfinibandDevice::Ptr infinibandDevice = device.objectCast<NetworkManager::InfinibandDevice>();
+        m_details << i18n("Type") << i18n("Infiniband");
+        if (infinibandDevice) {
+            m_details << i18n("MAC Address") << infinibandDevice->hwAddress();
+        }
+    } else if (m_type == NetworkManager::ConnectionSettings::Bond) {
+        NetworkManager::BondDevice::Ptr bondDevice = device.objectCast<NetworkManager::BondDevice>();
+        m_details << i18n("Type") << i18n("Bond");
+        if (bondDevice) {
+            m_details << i18n("MAC Address") << bondDevice->hwAddress();
+        }
+    } else if (m_type == NetworkManager::ConnectionSettings::Bridge) {
+        NetworkManager::BridgeDevice::Ptr bridgeDevice = device.objectCast<NetworkManager::BridgeDevice>();
+        m_details << i18n("Type") << i18n("Bridge");
+        if (bridgeDevice) {
+            m_details << i18n("MAC Address") << bridgeDevice->hwAddress();
+        }
+    } else if (m_type == NetworkManager::ConnectionSettings::Vlan) {
+        NetworkManager::VlanDevice::Ptr vlanDevice = device.objectCast<NetworkManager::VlanDevice>();
+        m_details << i18n("Type") << i18n("Vlan");
+        if (vlanDevice) {
+            m_details << i18n("Vlan ID") << QString("%1%").arg(vlanDevice->vlanId());
+            m_details << i18n("MAC Address") << vlanDevice->hwAddress();
+        }
+    } else if (m_type == NetworkManager::ConnectionSettings::Adsl) {
+        m_details << i18n("Type") << i18n("Adsl");
+    }
+#if NM_CHECK_VERSION (0, 9, 10)
+      else if (m_type == NetworkManager::ConnectionSettings::Team) {
+        NetworkManager::TeamDevice::Ptr teamDevice = device.objectCast<NetworkManager::TeamDevice>();
+        m_details << i18n("Type") << i18n("Team");
+        if (teamDevice) {
+            m_details << i18n("MAC Address") << teamDevice->hwAddress();
+        }
+    }
+#endif
+}
+
+void NetworkModelItem::dataUpdated(const QString& sourceName, const Plasma::DataEngine::Data& data)
+{
+    if (sourceName == m_uploadSource) {
+        m_upload = data["value"].toString();
+    } else if (sourceName == m_downloadSource) {
+        m_download = data["value"].toString();
+    }
+    Q_EMIT itemUpdated();
+}
+
+void NetworkModelItem::initializeDataEngine()
+{
+    m_engine = m_dataEngineConsumer->dataEngine("systemmonitor");
+
+    NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(m_devicePath);
+    if (!device) {
+        removeDataEngine();
+        return;
     }
 
-    m_details += "</table></qt>";
+    QString interfaceName = device->ipInterfaceName();
+    if (interfaceName.isEmpty()) {
+        interfaceName = device->interfaceName();
+    }
+
+    m_downloadSource = QString("network/interfaces/%1/receiver/data").arg(interfaceName);
+    m_uploadSource = QString("network/interfaces/%1/transmitter/data").arg(interfaceName);
+
+    setUpdateEnabled(true);
+}
+
+void NetworkModelItem::removeDataEngine()
+{
+    setUpdateEnabled(false);
+}
+
+void NetworkModelItem::setUpdateEnabled(bool enabled)
+{
+    Plasma::DataEngine * engine = m_dataEngineConsumer->dataEngine("systemmonitor");
+    NetworkManager::Device::Ptr device = NetworkManager::findNetworkInterface(m_devicePath);
+    if (engine->isValid()) {
+        int interval = 2000;
+        if (enabled) {
+            if (device) {
+                engine->connectSource(m_downloadSource, this, interval);
+                engine->connectSource(m_uploadSource, this, interval);
+            }
+        } else {
+            engine->disconnectSource(m_downloadSource, this);
+            engine->disconnectSource(m_uploadSource, this);
+        }
+    }
+    m_updateEnabled = enabled;
 }
