@@ -27,6 +27,9 @@
 #include <NetworkManagerQt/Device>
 #include <NetworkManagerQt/Utils>
 
+#include <Plasma/DataEngine>
+#include <Plasma/DataEngineConsumer>
+
 #include "networkmodel.h"
 #include "plasmanm_export.h"
 
@@ -50,17 +53,17 @@ public:
     NetworkManager::ActiveConnection::State connectionState() const;
     void setConnectionState(NetworkManager::ActiveConnection::State state);
 
-    QString details() const;
-
-    QString deviceName() const;
-    void setDeviceName(const QString& name);
+    QStringList details() const;
 
     QString devicePath() const;
+    void setDeviceName(const QString& name);
     void setDevicePath(const QString& path);
 
     QString deviceState() const;
     void setDeviceState(const NetworkManager::Device::State state);
 
+    QString download() const;
+
     bool duplicate() const;
 
     QString icon() const;
@@ -103,6 +106,8 @@ public:
 
     QString uni() const;
 
+    QString upload() const;
+
     QString uuid() const;
     void setUuid(const QString& uuid);
 
@@ -112,17 +117,29 @@ public:
     bool operator==(const NetworkModelItem * item) const;
 
 public Q_SLOTS:
+    void dataUpdated(const QString & sourceName, const Plasma::DataEngine::Data & data);
     void updateDetails();
 
+Q_SIGNALS:
+    void itemUpdated();
+
 private:
+    void initializeDataEngine();
+    void removeDataEngine();
+    void setUpdateEnabled(bool enabled);
+
     QString m_activeConnectionPath;
     QString m_connectionPath;
     NetworkManager::ActiveConnection::State m_connectionState;
     QString m_devicePath;
     QString m_deviceName;
     NetworkManager::Device::State m_deviceState;
-    QString m_details;
+    QStringList m_details;
+    QString m_download;
+    QString m_downloadSource;
     bool m_duplicate;
+    Plasma::DataEngine * m_engine;
+    Plasma::DataEngineConsumer * m_dataEngineConsumer;
     NetworkManager::WirelessSetting::NetworkMode m_mode;
     QString m_name;
     QString m_nsp;
@@ -133,6 +150,9 @@ private:
     QString m_ssid;
     QDateTime m_timestamp;
     NetworkManager::ConnectionSettings::ConnectionType m_type;
+    QString m_upload;
+    QString m_uploadSource;
+    bool m_updateEnabled;
     QString m_uuid;
     NetworkManager::VpnConnection::State m_vpnState;
 };
