@@ -1,5 +1,6 @@
 /*
     Copyright 2008-2010 Sebastian Kügler <sebas@kde.org>
+    Copyright 2013-2014 Jan Grulich <jgrulich@redhat.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -22,9 +23,7 @@
 #include "uiutils.h"
 
 // KDE
-#include <KDebug>
 #include <KLocale>
-#include <KGlobal>
 
 #include <NetworkManagerQt/BluetoothDevice>
 #include <NetworkManagerQt/Manager>
@@ -81,6 +80,11 @@ QString UiUtils::interfaceTypeLabel(const NetworkManager::Device::Type type, con
     case NetworkManager::Device::Vlan:
         deviceText = i18nc("title of the interface widget in nm's popup", "Virtual (vlan)");
         break;
+#if NM_CHECK_VERSION(0, 9, 10)
+    case NetworkManager::Device::Team:
+        deviceText = i18nc("title of the interface widget in nm's popup", "Virtual (team)");
+        break;
+#endif
     case NetworkManager::Device::Modem: {
         const NetworkManager::ModemDevice::Ptr nmModemIface = iface.objectCast<NetworkManager::ModemDevice>();
         if (nmModemIface) {
@@ -94,7 +98,7 @@ QString UiUtils::interfaceTypeLabel(const NetworkManager::Device::Type type, con
                 deviceText = i18nc("title of the interface widget in nm's popup", "Mobile Broadband");
                 break;
             case NetworkManager::ModemDevice::NoCapability:
-                kWarning() << "Unhandled modem sub type: NetworkManager::ModemDevice::NoCapability";
+                qWarning() << "Unhandled modem sub type: NetworkManager::ModemDevice::NoCapability";
                 break;
             }
         }
@@ -160,6 +164,11 @@ QString UiUtils::iconAndTitleForConnectionSettingsType(NetworkManager::Connectio
         text = i18n("Wireless");
         icon = "network-wireless";
         break;
+#if NM_CHECK_VERSION(0, 9, 10)
+    case ConnectionSettings::Team:
+        text = i18n("Team");
+        break;
+#endif
     default:
         text = i18n("Unknown connection type");
         break;
@@ -482,7 +491,7 @@ QString UiUtils::convertLockReasonToString(MMModemLock reason)
 QString UiUtils::convertNspTypeToString(WimaxNsp::NetworkType type)
 {
     switch (type) {
-        case WimaxNsp::Unknown: return i18nc("Unknown", "Unknown Wimax NSP type");
+        case WimaxNsp::Unknown: return i18nc("unknown Wimax NSP type", "Unknown");
         case WimaxNsp::Home: return i18n("Home");
         case WimaxNsp::Partner: return i18n("Partner");
         case WimaxNsp::RoamingPartner: return i18n("Roaming partner");
@@ -575,309 +584,22 @@ QString UiUtils::shortToolTipFromWirelessSecurity(NetworkManager::Utils::Wireles
     return tip;
 }
 
-QString UiUtils::connectionDetails(const Device::Ptr& device, const Connection::Ptr& connection, const QStringList& keys)
-{
-    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
-    QString details;
-
-    const bool connected = device && connection && device->activeConnection() &&
-                           device->activeConnection()->connection() == connection && device->activeConnection()->state() == ActiveConnection::Activated;
-
-    foreach (const QString& key, keys) {
-        if (key == "interface:name") {
-            if (device) {
-                QString name;
-                if (device->ipInterfaceName().isEmpty()) {
-                    name = device->interfaceName();
-                } else {
-                    name = device->ipInterfaceName();
-                }
-                details += QString(format).arg(i18n("System name:"), name);
-            }
-        } else if (key == "ipv4:address") {
-            if (device && device->ipV4Config().isValid() && connected) {
-                if (device->ipV4Config().addresses().isEmpty()) {
-                    continue;
-                }
-                QHostAddress addr = device->ipV4Config().addresses().first().ip();
-                if (!addr.isNull()) {
-                    details += QString(format).arg(i18n("IPv4 Address:"), addr.toString());
-                }
-            }
-        } else if (key == "ipv4:gateway") {
-            if (device && device->ipV4Config().isValid() && connected) {
-                if (device->ipV4Config().addresses().isEmpty()) {
-                    continue;
-                }
-                QHostAddress addr = device->ipV4Config().addresses().first().gateway();
-                if (!addr.isNull()) {
-                    details += QString(format).arg(i18n("IPv4 Gateway:"), addr.toString());
-                }
-            }
-        } else if (key == "ipv6:address") {
-            if (device && device->ipV6Config().isValid() && connected) {
-                if (device->ipV6Config().addresses().isEmpty()) {
-                    continue;
-                }
-                QHostAddress addr = device->ipV6Config().addresses().first().ip();
-                if (!addr.isNull()) {
-                    details += QString(format).arg(i18n("IPv6 Address:"), addr.toString());
-                }
-            }
-        } else if (key == "ipv6:gateway") {
-            if (device && device->ipV6Config().isValid() && connected) {
-                if (device->ipV6Config().addresses().isEmpty()) {
-                    continue;
-                }
-                QHostAddress addr = device->ipV6Config().addresses().first().gateway();
-                if (!addr.isNull() && addr.toString() != "::") {
-                    details += QString(format).arg(i18n("IPv6 Gateway:"), addr.toString());
-                }
-            }
-        } else if (key == "interface:driver") {
-            if (device) {
-                details += QString(format).arg(i18n("Driver:"), device->driver());
-            }
-        }
-    }
-
-    return details;
-}
-
-QString UiUtils::bluetoothDetails(const BluetoothDevice::Ptr& btDevice, const QStringList& keys)
-{
-    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
-    QString details;
-
-    foreach (const QString& key, keys) {
-        if (key == "bluetooth:name") {
-            if (btDevice) {
-                details += QString(format).arg(i18nc("Name", "Bluetooth name"), btDevice->name());
-            }
-        } else if (key == "interface:hardwareAddress") {
-            if (btDevice) {
-                details += QString(format).arg(i18n("MAC Address:"), btDevice->hardwareAddress());
-            }
-        }
-    }
-
-    return details;
-}
-
-QString UiUtils::modemDetails(const ModemDevice::Ptr& modemDevice, const QStringList& keys)
-{
-#if WITH_MODEMMANAGER_SUPPORT
-    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
-    QString details;
-    ModemManager::Modem::Ptr modemNetwork;
-    ModemManager::Modem3gpp::Ptr gsmNet;
-    ModemManager::ModemCdma::Ptr cdmaNet;
-
-    ModemManager::ModemDevice::Ptr modem = ModemManager::findModemDevice(modemDevice->udi());
-    if (modem) {
-        modemNetwork = modem->interface(ModemManager::ModemDevice::ModemInterface).objectCast<ModemManager::Modem>();
-        gsmNet = modem->interface(ModemManager::ModemDevice::GsmInterface).objectCast<ModemManager::Modem3gpp>();
-        cdmaNet = modem->interface(ModemManager::ModemDevice::CdmaInterface).objectCast<ModemManager::ModemCdma>();
-    }
-
-    foreach (const QString& key, keys) {
-        if (key == "mobile:operator") {
-            if (gsmNet) {
-                details += QString(format).arg(i18n("Operator:"), gsmNet->operatorName());
-            } else if (cdmaNet) {
-                details += QString(format).arg(i18n("Network ID:"), cdmaNet->nid());
-            }
-        } else if (key == "mobile:quality") {
-            if (modemNetwork) {
-                details += QString(format).arg(i18n("Signal Quality:"), QString("%1%").arg(modemNetwork->signalQuality().signal));
-            }
-        } else if (key == "mobile:technology") {
-            if (modemNetwork) {
-                details += QString(format).arg(i18n("Access Technology:"), UiUtils::convertAccessTechnologyToString(modemNetwork->accessTechnologies()));
-            }
-        } else if (key == "mobile:mode") {
-            if (modemNetwork) {
-                details += QString(format).arg(i18n("Allowed Mode:"), UiUtils::convertAllowedModeToString(modemNetwork->currentModes().allowed));
-            }
-        } else if (key == "mobile:unlock") {
-            if (modemNetwork) {
-                details += QString(format).arg(i18n("Unlock Required:"), UiUtils::convertLockReasonToString(modemNetwork->unlockRequired()));
-            }
-        } else if (key == "mobile:imei") {
-            if (modemNetwork) {
-                details += QString(format).arg(i18n("IMEI:"), modemNetwork->equipmentIdentifier());
-            }
-        } else if (key == "mobile:imsi") {
-            if (modemDevice) {
-                ModemManager::Sim::Ptr simCard;
-                simCard = modemDevice->getModemCardIface();
-                if (simCard) {
-                    details += QString(format).arg(i18n("IMSI:"), simCard->imsi());
-                }
-            }
-        }
-    }
-    return details;
-#else
-    Q_UNUSED(modemDevice)
-    Q_UNUSED(keys)
-    return QString();
-#endif
-}
-
-QString UiUtils::vpnDetails(const VpnConnection::Ptr& vpnConnection, const VpnSetting::Ptr& vpnSetting, const QStringList& keys)
-{
-    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
-    QString details;
-
-    foreach (const QString& key, keys) {
-        if (key == "vpn:plugin") {
-            if (vpnSetting) {
-                details += QString(format).arg(i18n("VPN plugin:"), vpnSetting->serviceType().section('.', -1));
-            }
-        } else if (key == "vpn:banner") {
-            if (vpnConnection && !vpnConnection->banner().isEmpty()) {
-                details += QString(format).arg(i18n("Banner:"), vpnConnection->banner().simplified());
-            }
-        }
-    }
-
-    return details;
-}
-
-QString UiUtils::wimaxDetails(const NetworkManager::WimaxDevice::Ptr& wimaxDevice, const WimaxNsp::Ptr& wimaxNsp, const NetworkManager::Connection::Ptr& connection, const QStringList& keys)
-{
-    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
-    QString details;
-
-    const bool connected = wimaxDevice && connection && wimaxDevice->activeConnection() &&
-                           wimaxDevice->activeConnection()->connection() == connection && wimaxDevice->activeConnection()->state() == ActiveConnection::Activated;
-
-    foreach (const QString& key, keys) {
-        if (key == "wimax:bsid") {
-            if (connected && wimaxDevice) {
-                details += QString(format).arg(i18n("Bsid:"), wimaxDevice->bsid());
-            }
-        } else if (key == "wimax:nsp") {
-            if (wimaxNsp) {
-                details += QString(format).arg(i18n("NSP Name:"), wimaxNsp->name());
-            }
-        } else if (key == "wimax:signal") {
-            if (wimaxNsp) {
-                details += QString(format).arg(i18n("Signal Quality:"), i18n("%1%", wimaxNsp->signalQuality()));
-            }
-        } else if (key == "wimax:type") {
-            if (wimaxNsp) {
-                details += QString(format).arg(i18n("Network Type:"), UiUtils::convertNspTypeToString(wimaxNsp->networkType()));
-            }
-        }
-    }
-
-    return details;
-}
-
-QString UiUtils::wiredDetails(const WiredDevice::Ptr& wiredDevice, const NetworkManager::Connection::Ptr& connection, const QStringList& keys)
-{
-    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
-    QString details;
-
-    const bool connected = wiredDevice && connection && wiredDevice->activeConnection() &&
-                           wiredDevice->activeConnection()->connection() == connection && wiredDevice->activeConnection()->state() == ActiveConnection::Activated;
-
-    foreach (const QString& key, keys) {
-        if (key == "interface:bitrate") {
-            if (wiredDevice && connected) {
-                details += QString(format).arg(i18n("Connection speed:"), UiUtils::connectionSpeed(wiredDevice->bitRate()));
-            }
-        } else if (key == "interface:hardwareaddress") {
-            if (wiredDevice) {
-                details += QString(format).arg(i18n("MAC Address:"), wiredDevice->permanentHardwareAddress());
-            }
-        }
-    }
-
-    return details;
-}
-
-QString UiUtils::wirelessDetails(const WirelessDevice::Ptr& wirelessDevice, const AccessPoint::Ptr& ap, const NetworkManager::Connection::Ptr& connection, const QStringList& keys)
-{
-    const QString format = "<tr><td align=\"right\" width=\"50%\"><b>%1</b></td><td align=\"left\" width=\"50%\">&nbsp;%2</td></tr>";
-    QString details;
-
-    const bool connected = wirelessDevice && connection && wirelessDevice->activeConnection() &&
-                           wirelessDevice->activeConnection()->connection() == connection && wirelessDevice->activeConnection()->state() == ActiveConnection::Activated;
-
-
-    foreach (const QString& key, keys) {
-        if (key == "interface:bitrate") {
-            if (wirelessDevice && connected) {
-                details += QString(format).arg(i18n("Connection speed:"), UiUtils::connectionSpeed(wirelessDevice->bitRate()));
-            }
-        } else if (key == "interface:hardwareaddress") {
-            if (wirelessDevice) {
-                details += QString(format).arg(i18n("MAC Address:"), wirelessDevice->permanentHardwareAddress());
-            }
-        } else if (key == "wireless:mode") {
-            if (wirelessDevice) {
-                details += QString(format).arg(i18n("Mode:"), UiUtils::operationModeToString(wirelessDevice->mode()));
-            }
-        } else if (key == "wireless:signal") {
-            if (ap) {
-                details += QString(format).arg(i18n("Signal strength:"), i18n("%1%", ap->signalStrength()));
-            }
-        } else if (key == "wireless:ssid") {
-            if (ap) {
-                details += QString(format).arg(i18n("Access point (SSID):"), ap->ssid());
-            }
-        } else if (key == "wireless:accesspoint") {
-            if (ap) {
-                details += QString(format).arg(i18n("Access point (BSSID):"), ap->hardwareAddress());
-            }
-        } else if (key == "wireless:channel") {
-            if (ap) {
-                details += QString(format).arg(i18nc("Wifi AP channel and frequency", "Channel:"), i18n("%1 (%2 MHz)", NetworkManager::Utils::findChannel(ap->frequency()), ap->frequency()));
-            }
-        } else if (key == "wireless:security") {
-            NetworkManager::Utils::WirelessSecurityType security = Utils::Unknown;
-            if (ap) {
-                security = NetworkManager::Utils::findBestWirelessSecurity(wirelessDevice->wirelessCapabilities(), true, (wirelessDevice->mode() == NetworkManager::WirelessDevice::Adhoc),
-                                                                           ap->capabilities(), ap->wpaFlags(), ap->rsnFlags());
-                if (security != Utils::Unknown) {
-                    details += QString(format).arg(i18n("Security:"), UiUtils::labelFromWirelessSecurity(security));
-                }
-            } else if (connection) {
-                // Necessary for example for AdHoc connections
-                security = Utils::securityTypeFromConnectionSetting(connection->settings());
-                if (security != Utils::Unknown) {
-                    details += QString(format).arg(i18n("Security:"), UiUtils::labelFromWirelessSecurity(security));
-                }
-            }
-        } else if (key == "wireless:band") {
-            if (ap) {
-                details += QString(format).arg(i18n("Frequency band:"), UiUtils::wirelessBandToString(NetworkManager::Utils::findFrequencyBand(ap->frequency())));
-            }
-        }
-    }
-
-    return details;
-}
-
 QString UiUtils::formatDateRelative(const QDateTime & lastUsed)
 {
     QString lastUsedText;
     if (lastUsed.isValid()) {
         const QDateTime now = QDateTime::currentDateTime();
         if (lastUsed.daysTo(now) == 0 ) {
-            int secondsAgo = lastUsed.secsTo(now);
+            const int secondsAgo = lastUsed.secsTo(now);
             if (secondsAgo < (60 * 60 )) {
-                int minutesAgo = secondsAgo / 60;
+                const int minutesAgo = secondsAgo / 60;
                 lastUsedText = i18ncp(
                                    "Label for last used time for a network connection used in the last hour, as the number of minutes since usage",
                                    "One minute ago",
                                    "%1 minutes ago",
                                    minutesAgo);
             } else {
-                int hoursAgo = secondsAgo / (60 * 60);
+                const int hoursAgo = secondsAgo / (60 * 60);
                 lastUsedText = i18ncp(
                                    "Label for last used time for a network connection used in the last day, as the number of hours since usage",
                                    "One hour ago",
@@ -887,7 +609,7 @@ QString UiUtils::formatDateRelative(const QDateTime & lastUsed)
         } else if (lastUsed.daysTo(now) == 1) {
             lastUsedText = i18nc("Label for last used time for a network connection used the previous day", "Yesterday");
         } else {
-            lastUsedText = KGlobal::locale()->formatDate(lastUsed.date(), KLocale::ShortDate);
+            lastUsedText = KLocale::global()->formatDate(lastUsed.date(), KLocale::ShortDate);
         }
     } else {
         lastUsedText =  i18nc("Label for last used time for a "
@@ -921,7 +643,7 @@ QString UiUtils::formatLastUsedDateRelative(const QDateTime & lastUsed)
         } else if (lastUsed.daysTo(now) == 1) {
             lastUsedText = i18nc("Label for last used time for a network connection used the previous day", "Last used yesterday");
         } else {
-            lastUsedText = i18n("Last used on %1", KGlobal::locale()->formatDate(lastUsed.date(), KLocale::ShortDate));
+            lastUsedText = i18n("Last used on %1", KLocale::global()->formatDate(lastUsed.date(), KLocale::ShortDate));
         }
     } else {
         lastUsedText =  i18nc("Label for last used time for a "
