@@ -23,23 +23,24 @@
 #include "openconnectauthworkerthread.h"
 #include "ui_openconnectauth.h"
 
-#include <KDialog>
+#include <QDialog>
+#include <KLocalizedString>
 #include <QPushButton>
 #include <QString>
 #include <QLabel>
 #include <QEventLoop>
 #include <QFormLayout>
 #include <KLineEdit>
-#include <KDialogButtonBox>
-#include <KPushButton>
+#include <KIcon>
+#include <QDialogButtonBox>
+#include <QPushButton>
 #include <KComboBox>
-#include <KDebug>
+#include <QDebug>
 #include <QDomDocument>
 #include <QMutex>
 #include <QWaitCondition>
 #include <QCryptographicHash>
 #include <QFile>
-#include <QTimer>
 
 #include "nm-openconnect-service.h"
 
@@ -66,14 +67,13 @@ public:
     Ui_OpenconnectAuth ui;
     NetworkManager::VpnSetting::Ptr setting;
     struct openconnect_info *vpninfo;
+    QStringList certificateFingerprints;
     NMStringMap secrets;
-    NMStringMap tmpSecrets;
     QMutex mutex;
     QWaitCondition workerWaiting;
     OpenconnectAuthWorkerThread *worker;
     QList<VPNHost> hosts;
     bool userQuit;
-    bool formGroupChanged;
     int cancelPipes[2];
     QList<QPair<QString, int> > serverLog;
 
@@ -88,8 +88,6 @@ OpenconnectAuthWidget::OpenconnectAuthWidget(const NetworkManager::VpnSetting::P
     d->setting = setting;
     d->ui.setupUi(this);
     d->userQuit = false;
-    d->formGroupChanged = false;
-
     if (pipe2(d->cancelPipes, O_NONBLOCK|O_CLOEXEC)) {
         // Should never happen. Just don't do real cancellation if it does
         d->cancelPipes[0] = -1;
@@ -99,12 +97,13 @@ OpenconnectAuthWidget::OpenconnectAuthWidget(const NetworkManager::VpnSetting::P
     connect(d->ui.cmbLogLevel, SIGNAL(currentIndexChanged(int)), this, SLOT(logLevelChanged(int)));
     connect(d->ui.viewServerLog, SIGNAL(toggled(bool)), this, SLOT(viewServerLogToggled(bool)));
     connect(d->ui.btnConnect, SIGNAL(clicked()), this, SLOT(connectHost()));
+    connect(d->ui.cmbHosts, SIGNAL(currentIndexChanged(int)), this, SLOT(connectHost()));
 
     d->ui.cmbLogLevel->setCurrentIndex(OpenconnectAuthWidgetPrivate::Debug);
     d->ui.btnConnect->setIcon(KIcon("network-connect"));
     d->ui.viewServerLog->setChecked(false);
 
-    d->worker = new OpenconnectAuthWorkerThread(&d->mutex, &d->workerWaiting, &d->userQuit, &d->formGroupChanged, d->cancelPipes[0]);
+    d->worker = new OpenconnectAuthWorkerThread(&d->mutex, &d->workerWaiting, &d->userQuit, d->cancelPipes[0]);
 
     // gets the pointer to struct openconnect_info (defined in openconnect.h), which contains data that OpenConnect needs,
     // and which needs to be populated with settings we get from NM, like host, certificate or private key
@@ -119,9 +118,6 @@ OpenconnectAuthWidget::OpenconnectAuthWidget(const NetworkManager::VpnSetting::P
     readConfig();
     readSecrets();
 
-    // This might be set by readSecrets() so don't connect it until now
-    connect(d->ui.cmbHosts, SIGNAL(currentIndexChanged(int)), this, SLOT(connectHost()));
-
     KAcceleratorManager::manage(this);
 }
 
@@ -161,7 +157,7 @@ void OpenconnectAuthWidget::readConfig()
     }
     if (!dataMap[NM_OPENCONNECT_KEY_CACERT].isEmpty()) {
         const QByteArray crt = QFile::encodeName(dataMap[NM_OPENCONNECT_KEY_CACERT]);
-        openconnect_set_cafile(d->vpninfo, OC3DUP(crt.data()));
+        openconnect_set_cafile(d->vpninfo, strdup(crt.data()));
     }
     if (dataMap[NM_OPENCONNECT_KEY_CSD_ENABLE] == "yes") {
         char *wrapper;
@@ -174,12 +170,12 @@ void OpenconnectAuthWidget::readConfig()
     }
     if (!dataMap[NM_OPENCONNECT_KEY_PROXY].isEmpty()) {
         const QByteArray proxy = QFile::encodeName(dataMap[NM_OPENCONNECT_KEY_PROXY]);
-        openconnect_set_http_proxy(d->vpninfo, OC3DUP(proxy.data()));
+        openconnect_set_http_proxy(d->vpninfo, strdup(proxy.data()));
     }
     if (!dataMap[NM_OPENCONNECT_KEY_USERCERT].isEmpty()) {
         const QByteArray crt = QFile::encodeName(dataMap[NM_OPENCONNECT_KEY_USERCERT]);
         const QByteArray key = QFile::encodeName(dataMap[NM_OPENCONNECT_KEY_PRIVKEY]);
-        openconnect_set_client_cert (d->vpninfo, OC3DUP(crt.data()), OC3DUP(key.data()));
+        openconnect_set_client_cert (d->vpninfo, strdup(crt.data()), strdup(key.data()));
 
         if (!crt.isEmpty() && dataMap[NM_OPENCONNECT_KEY_PEM_PASSPHRASE_FSID] == "yes") {
             openconnect_passphrase_from_fsid(d->vpninfo);
@@ -193,6 +189,10 @@ void OpenconnectAuthWidget::readSecrets()
 
     d->secrets = d->setting->secrets();
 
+    if (!d->secrets[NM_OPENCONNECT_KEY_GWCERT].isEmpty()) {
+        d->certificateFingerprints.append(d->secrets[NM_OPENCONNECT_KEY_GWCERT]);
+    }
+
     if (!d->secrets["xmlconfig"].isEmpty()) {
         const QByteArray config = QByteArray::fromBase64(d->secrets["xmlconfig"].toAscii());
 
@@ -230,17 +230,17 @@ void OpenconnectAuthWidget::readSecrets()
 
     if (d->secrets["autoconnect"] == "yes") {
         d->ui.chkAutoconnect->setChecked(true);
-        QTimer::singleShot(0, this, SLOT(connectHost()));
+        connectHost();
     }
-
-    if (d->secrets["save_passwords"] == "yes") {
-        d->ui.chkStorePasswords->setChecked(true);
+    if (!d->secrets["certsigs"].isEmpty()) {
+        d->certificateFingerprints.append(d->secrets["certsigs"].split('\t'));
     }
+    d->certificateFingerprints.removeDuplicates();
 }
 
 void OpenconnectAuthWidget::acceptDialog()
 {
-    KDialog *dialog = qobject_cast<KDialog*>(parentWidget());
+    QDialog *dialog = qobject_cast<QDialog*>(parentWidget());
     if (dialog) {
         dialog->accept();
     }
@@ -270,11 +270,11 @@ void OpenconnectAuthWidget::connectHost()
     i = d->ui.cmbHosts->itemData(i).toInt();
     const VPNHost &host = d->hosts.at(i);
     if (openconnect_parse_url(d->vpninfo, host.address.toAscii().data())) {
-        kWarning() << "Failed to parse server URL" << host.address;
-        openconnect_set_hostname(d->vpninfo, OC3DUP(host.address.toAscii().data()));
+        qWarning() << "Failed to parse server URL" << host.address;
+        openconnect_set_hostname(d->vpninfo, strdup(host.address.toAscii().data()));
     }
     if (!openconnect_get_urlpath(d->vpninfo) && !host.group.isEmpty())
-        openconnect_set_urlpath(d->vpninfo, OC3DUP(host.group.toAscii().data()));
+        openconnect_set_urlpath(d->vpninfo, strdup(host.group.toAscii().data()));
     d->secrets["lasthost"] = host.name;
     addFormInfo(QLatin1String("dialog-information"), i18n("Contacting host, please wait..."));
     d->worker->start();
@@ -296,16 +296,12 @@ QVariantMap OpenconnectAuthWidget::setting(bool agentOwned) const
     secrets.insert(QLatin1String(NM_OPENCONNECT_KEY_COOKIE), QLatin1String(openconnect_get_cookie(d->vpninfo)));
     openconnect_clear_cookie(d->vpninfo);
 
-#if OPENCONNECT_CHECK_VER(5,0)
-    const char *fingerprint = openconnect_get_peer_cert_hash(d->vpninfo);
-#else
     OPENCONNECT_X509 *cert = openconnect_get_peer_cert(d->vpninfo);
     char fingerprint[41];
     openconnect_get_cert_sha1(d->vpninfo, cert, fingerprint);
-#endif
     secrets.insert(QLatin1String(NM_OPENCONNECT_KEY_GWCERT), QLatin1String(fingerprint));
+    secrets.insert(QLatin1String("certsigs"), d->certificateFingerprints.join("\t"));
     secrets.insert(QLatin1String("autoconnect"), d->ui.chkAutoconnect->isChecked() ? "yes" : "no");
-    secrets.insert(QLatin1String("save_passwords"), d->ui.chkStorePasswords->isChecked() ? "yes" : "no");
 
     NMStringMap::iterator i = secrets.begin();
     while (i != secrets.end()) {
@@ -316,12 +312,6 @@ QVariantMap OpenconnectAuthWidget::setting(bool agentOwned) const
     }
 
     secretData.insert("secrets", QVariant::fromValue<NMStringMap>(secrets));
-
-    // These secrets are not officially part of the secrets which would be returned back to NetworkManager. We just
-    // need to somehow get them to our secret agent which will handle them separately and store them.
-    if (!d->tmpSecrets.isEmpty()) {
-        secretData.insert("tmp-secrets", QVariant::fromValue<NMStringMap>(d->tmpSecrets));
-    }
     return secretData;
 }
 
@@ -459,12 +449,14 @@ void OpenconnectAuthWidget::processAuthForm(struct oc_auth_form *form)
                     cmb->setCurrentIndex(i);
                     if (sopt == AUTHGROUP_OPT(form) &&
                         i != AUTHGROUP_SELECTION(form)) {
-                        QTimer::singleShot(0, this, SLOT(formGroupChanged()));
+                        // XXX: Immediately return OC_FORM_RESULT_NEWGROUP to
+                        //      change group
                     }
                 }
             }
             if (sopt == AUTHGROUP_OPT(form)) {
-                connect(cmb, SIGNAL(currentIndexChanged(int)), this, SLOT(formGroupChanged()));
+                // TODO: Hook up signal when the KComboBox entry changes, to
+                //       return OC_FORM_RESULT_NEWGROUP
             }
             widget = qobject_cast<QWidget*>(cmb);
         }
@@ -478,7 +470,7 @@ void OpenconnectAuthWidget::processAuthForm(struct oc_auth_form *form)
     d->ui.loginBoxLayout->addWidget(togglePasswordMode);
     if (passwordnumber == 0)
         togglePasswordMode->setVisible(false);
-    KDialogButtonBox *box = new KDialogButtonBox(this);
+    QDialogButtonBox *box = new QDialogButtonBox(this);
     QPushButton *btn = box->addButton(QDialogButtonBox::Ok);
     btn->setText(i18n("Login"));
     btn->setDefault(true);
@@ -493,22 +485,13 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
 {
     Q_D(OpenconnectAuthWidget);
 
-    const QString host = QLatin1String(openconnect_get_hostname(d->vpninfo));
-    const QString port = QString::number(openconnect_get_port(d->vpninfo));
-    const QString key = QString("certificate:%1:%2").arg(host,  port);
-    const QString value = d->secrets.value(key);
-
-#if !OPENCONNECT_CHECK_VER(5,0)
-#define openconnect_check_peer_cert_hash(v,d) strcmp(d, fingerprint.toUtf8().data())
-#endif
-
-    if (openconnect_check_peer_cert_hash(d->vpninfo, value.toUtf8().data())) {
+    if (!d->certificateFingerprints.contains(fingerprint)) {
         QWidget *widget = new QWidget();
         QVBoxLayout *verticalLayout;
         QHBoxLayout *horizontalLayout;
         QLabel *icon;
         QLabel *infoText;
-        KTextBrowser *certificate;
+        QTextBrowser *certificate;
 
         verticalLayout = new QVBoxLayout(widget);
         horizontalLayout = new QHBoxLayout(widget);
@@ -530,7 +513,7 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
 
         verticalLayout->addLayout(horizontalLayout);
 
-        certificate = new KTextBrowser(widget);
+        certificate = new QTextBrowser(widget);
         certificate->setTextInteractionFlags(Qt::TextSelectableByMouse);
         certificate->setOpenLinks(false);
 
@@ -542,11 +525,17 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
         infoText->setWordWrap(true);
         certificate->setText(peerCert);
 
-        QWeakPointer<KDialog> dialog = new KDialog(this);
+        QPointer<QDialog> dialog = new QDialog(this);
         dialog.data()->setWindowModality(Qt::WindowModal);
-        dialog.data()->setButtons(KDialog::Yes | KDialog::No);
-        dialog.data()->setMainWidget(widget);
-        if(dialog.data()->exec() == KDialog::Yes) {
+        dialog->setLayout(new QVBoxLayout);
+        QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel, dialog);
+        connect(buttons, SIGNAL(accepted()), dialog, SLOT(accept()));
+        connect(buttons, SIGNAL(rejected()), dialog, SLOT(reject()));
+        dialog->layout()->addWidget(widget);
+        dialog->layout()->addWidget(buttons);
+
+        if(dialog.data()->exec() == QDialog::Accepted) {
+            d->certificateFingerprints.append(fingerprint);
             *accepted = true;
         } else {
             *accepted = false;
@@ -558,28 +547,18 @@ void OpenconnectAuthWidget::validatePeerCert(const QString &fingerprint,
     } else {
         *accepted = true;
     }
-    if (*accepted)
-        d->secrets.insert(key, QString(fingerprint));
     d->mutex.lock();
     d->workerWaiting.wakeAll();
     d->mutex.unlock();
 }
 
-void OpenconnectAuthWidget::formGroupChanged()
-{
-    Q_D(OpenconnectAuthWidget);
-
-    d->formGroupChanged = true;
-    formLoginClicked();
-}
-
 // Writes the user input from the form into the oc_auth_form structs we got from
 // libopenconnect, and wakes the worker thread up to try to log in and obtain a
 // cookie with this data
 void OpenconnectAuthWidget::formLoginClicked()
 {
     Q_D(OpenconnectAuthWidget);
-
+    /// XXX: This, or something like it, needs to be called when the KComboBox for the auth group changes too.
     const int lastIndex = d->ui.loginBoxLayout->count() - 1;
     QLayout *layout = d->ui.loginBoxLayout->itemAt(lastIndex - 2)->layout();
     struct oc_auth_form *form = (struct oc_auth_form *) d->ui.loginBoxLayout->itemAt(lastIndex)->widget()->property("openconnect_form").value<quintptr>();
@@ -593,21 +572,18 @@ void OpenconnectAuthWidget::formLoginClicked()
             if (opt->type == OC_FORM_OPT_PASSWORD || opt->type == OC_FORM_OPT_TEXT) {
                 KLineEdit *le = qobject_cast<KLineEdit*>(widget);
                 QByteArray text = le->text().toUtf8();
-                openconnect_set_option_value(opt, text.data());
+                opt->value = strdup(text.data());
                 if (opt->type == OC_FORM_OPT_TEXT) {
-                    d->secrets.insert(key, le->text());
-                } else {
-                    d->tmpSecrets.insert(key, le->text());
+                    d->secrets.insert(key,le->text());
                 }
             } else if (opt->type == OC_FORM_OPT_SELECT) {
                 KComboBox *cbo = qobject_cast<KComboBox*>(widget);
                 QByteArray text = cbo->itemData(cbo->currentIndex()).toString().toAscii();
-                openconnect_set_option_value(opt, text.data());
+                opt->value = strdup(text.data());
                 d->secrets.insert(key,cbo->itemData(cbo->currentIndex()).toString());
             }
         }
     }
-
     deleteAllFromLayout(d->ui.loginBoxLayout);
     d->workerWaiting.wakeAll();
 }
@@ -655,7 +631,7 @@ void OpenconnectAuthWidget::viewServerLogToggled(bool toggled)
     d->ui.lblLogLevel->setVisible(toggled);
     d->ui.cmbLogLevel->setVisible(toggled);
     if (toggled) {
-        QLayoutItem *item = d->ui.verticalLayout->takeAt(5);
+        QLayoutItem *item = d->ui.verticalLayout->takeAt(4);
         if (item) {
             delete item;
         }
