@@ -43,20 +43,6 @@ extern "C"
 class OpenconnectAuthStaticWrapper
 {
 public:
-#if OPENCONNECT_CHECK_VER(5,0)
-    static int writeNewConfig(void *obj, const char *str, int num)
-    {
-        if (obj)
-            return static_cast<OpenconnectAuthWorkerThread*>(obj)->writeNewConfig(str, num);
-        return -1;
-    }
-    static int validatePeerCert(void *obj, const char *str)
-    {
-        if (obj)
-            return static_cast<OpenconnectAuthWorkerThread*>(obj)->validatePeerCert(NULL, str);
-        return -1;
-    }
-#else
     static int writeNewConfig(void *obj, char *str, int num)
     {
         if (obj)
@@ -69,8 +55,7 @@ public:
             return static_cast<OpenconnectAuthWorkerThread*>(obj)->validatePeerCert(cert, str);
         return -1;
     }
-#endif
-	static int processAuthForm(void *obj, struct oc_auth_form *form)
+    static int processAuthForm(void *obj, struct oc_auth_form *form)
     {
         if (obj)
             return static_cast<OpenconnectAuthWorkerThread*>(obj)->processAuthFormP(form);
@@ -87,8 +72,8 @@ public:
     }
 };
 
-OpenconnectAuthWorkerThread::OpenconnectAuthWorkerThread(QMutex *mutex, QWaitCondition *waitForUserInput, bool *userDecidedToQuit, bool *formGroupChanged, int cancelFd)
-	: QThread(), m_mutex(mutex), m_waitForUserInput(waitForUserInput), m_userDecidedToQuit(userDecidedToQuit), m_formGroupChanged(formGroupChanged)
+OpenconnectAuthWorkerThread::OpenconnectAuthWorkerThread(QMutex *mutex, QWaitCondition *waitForUserInput, bool *userDecidedToQuit, int cancelFd)
+    : QThread(), m_mutex(mutex), m_waitForUserInput(waitForUserInput), m_userDecidedToQuit(userDecidedToQuit)
 {
     m_openconnectInfo = openconnect_vpninfo_new((char*)"OpenConnect VPN Agent (PlasmaNM - running on KDE)",
                                                 OpenconnectAuthStaticWrapper::validatePeerCert,
@@ -123,7 +108,7 @@ struct openconnect_info* OpenconnectAuthWorkerThread::getOpenconnectInfo()
     return m_openconnectInfo;
 }
 
-int OpenconnectAuthWorkerThread::writeNewConfig(const char *buf, int buflen)
+int OpenconnectAuthWorkerThread::writeNewConfig(char *buf, int buflen)
 {
     Q_UNUSED(buflen)
     if (*m_userDecidedToQuit)
@@ -154,16 +139,10 @@ static char *openconnect_get_cert_details(struct openconnect_info *vpninfo,
 }
 #endif
 
-int OpenconnectAuthWorkerThread::validatePeerCert(void *cert, const char *reason)
+int OpenconnectAuthWorkerThread::validatePeerCert(OPENCONNECT_X509 *cert, const char *reason)
 {
     if (*m_userDecidedToQuit)
         return -EINVAL;
-
-#if OPENCONNECT_CHECK_VER(5,0)
-    (void)cert;
-    const char *fingerprint = openconnect_get_peer_cert_hash(m_openconnectInfo);
-    char *details = openconnect_get_peer_cert_details(m_openconnectInfo);
-#else
     char fingerprint[41];
     int ret = 0;
 
@@ -172,7 +151,7 @@ int OpenconnectAuthWorkerThread::validatePeerCert(void *cert, const char *reason
         return ret;
 
     char *details = openconnect_get_cert_details(m_openconnectInfo, cert);
-#endif
+
     bool accepted = false;
     m_mutex->lock();
     QString qFingerprint(fingerprint);
@@ -181,7 +160,7 @@ int OpenconnectAuthWorkerThread::validatePeerCert(void *cert, const char *reason
     emit validatePeerCert(qFingerprint, qCertinfo, qReason, &accepted);
     m_waitForUserInput->wait(m_mutex);
     m_mutex->unlock();
-    openconnect_free_cert_info(m_openconnectInfo, details);
+    ::free(details);
     if (*m_userDecidedToQuit)
         return -EINVAL;
 
@@ -198,15 +177,14 @@ int OpenconnectAuthWorkerThread::processAuthFormP(struct oc_auth_form *form)
         return -1;
 
     m_mutex->lock();
-    *m_formGroupChanged = false;
     emit processAuthForm(form);
     m_waitForUserInput->wait(m_mutex);
     m_mutex->unlock();
     if (*m_userDecidedToQuit)
         return OC_FORM_RESULT_CANCELLED;
 
-    if (*m_formGroupChanged)
-        return OC_FORM_RESULT_NEWGROUP;
+    // TODO : If group changed, return OC_FORM_RESULT_NEWGROUP
+
     return OC_FORM_RESULT_OK;
 }
 
