@@ -1,8 +1,6 @@
 /*
     Copyright 2008 Will Stephenson <wstephenson@kde.org>
     Copyright 2011-2012 Rajeesh K Nambiar <rajeeshknambiar@gmail.com>
-    Copyright 2011 Ilia Kats <ilia-kats@gmx.net>
-    Copyright 2012-2014 Lamarque V. Souza <lamarque@kde.org>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -25,8 +23,8 @@
 
 #include <QStringBuilder>
 #include <KPluginFactory>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KStandardDirs>
 
 #include <NetworkManagerQt/Connection>
 #include <NetworkManagerQt/VpnSetting>
@@ -37,11 +35,7 @@
 
 #include "nm-openvpn-service.h"
 
-//#include <nm-setting-ip4-config.h>
-#define NM_SETTING_IP4_CONFIG_NEVER_DEFAULT "never-default"
-
-K_PLUGIN_FACTORY(OpenVpnUiPluginFactory, registerPlugin<OpenVpnUiPlugin>();)
-K_EXPORT_PLUGIN(OpenVpnUiPluginFactory("plasmanetworkmanagement_openvpnui"))
+K_PLUGIN_FACTORY_WITH_JSON(OpenVpnUiPluginFactory, "plasmanetworkmanagement_openvpnui.json", registerPlugin<OpenVpnUiPlugin>();)
 
 #define AUTH_TAG "auth"
 #define AUTH_USER_PASS_TAG "auth-user-pass"
@@ -70,18 +64,6 @@ K_EXPORT_PLUGIN(OpenVpnUiPluginFactory("plasmanetworkmanagement_openvpnui"))
 #define TLS_CLIENT_TAG "tls-client"
 #define TLS_REMOTE_TAG "tls-remote"
 #define TUNMTU_TAG "tun-mtu"
-#define KEY_DIRECTION_TAG "key-direction"
-
-#define BEGIN_KEY_CA_TAG "<ca>"
-#define END_KEY_CA_TAG "</ca>"
-#define BEGIN_KEY_CERT_TAG "<cert>"
-#define END_KEY_CERT_TAG "</cert>"
-#define BEGIN_KEY_KEY_TAG "<key>"
-#define END_KEY_KEY_TAG "</key>"
-#define BEGIN_KEY_SECRET_TAG "<secret>"
-#define END_KEY_SECRET_TAG "</secret>"
-#define BEGIN_TLS_AUTH_TAG "<tls-auth>"
-#define END_TLS_AUTH_TAG "</tls_auth>"
 
 #define PROC_TYPE_TAG "Proc-Type: 4,ENCRYPTED"
 #define PKCS8_TAG "-----BEGIN ENCRYPTED PRIVATE KEY-----"
@@ -184,16 +166,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
         return result;
     }
 
-    bool copyCertificates;
-    KMessageBox::ButtonCode buttonCode;
-    if (KMessageBox::shouldBeShownYesNo(QLatin1String("copyCertificatesDialog"), buttonCode)) {
-        copyCertificates = KMessageBox::questionYesNo(0, i18n("Do you want to copy your certificates to %1?", KStandardDirs::locateLocal("data", "networkmanagement/certificates/")),
-                                   i18n("Copy certificates"), KStandardGuiItem::yes(), KStandardGuiItem::no(), QLatin1String("copyCertificatesDialog")) == KMessageBox::Yes;
-    } else {
-        copyCertificates = buttonCode == KMessageBox::Yes;
-    }
-
-    const QString connectionName = QFileInfo(fileName).completeBaseName();
     NMStringMap dataMap;
     NMStringMap secretData;
     QVariantMap ipv4Data;
@@ -206,7 +178,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
     bool proxy_set = false;
     bool have_pass = false;
     bool have_sk = false;
-    int key_direction = -1;
 
     QTextStream in(&impFile);
     while (!in.atEnd()) {
@@ -398,42 +369,22 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
         }
         if (key_value[0] == CA_TAG && key_value.count() > 1) {
             key_value[1] = line.right(line.length() - line.indexOf(QRegExp("\\s"))); // Get whole string after key
-            if (copyCertificates) {
-                const QString absoluteFilePath = tryToCopyToCertificatesDirectory(connectionName, unQuote(key_value[1], fileName));
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_CA), absoluteFilePath);
-            } else {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_CA), unQuote(key_value[1], fileName));
-            }
+            dataMap.insert(QLatin1String(NM_OPENVPN_KEY_CA), unQuote(key_value[1], fileName));
             continue;
         }
         if (key_value[0] == CERT_TAG && key_value.count() > 1) {
             key_value[1] = line.right(line.length() - line.indexOf(QRegExp("\\s"))); // Get whole string after key
-            if (copyCertificates) {
-                const QString absoluteFilePath = tryToCopyToCertificatesDirectory(connectionName, unQuote(key_value[1], fileName));
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_CERT), absoluteFilePath);
-            } else {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_CERT), unQuote(key_value[1], fileName));
-            }
+            dataMap.insert(QLatin1String(NM_OPENVPN_KEY_CERT), unQuote(key_value[1], fileName));
             continue;
         }
         if (key_value[0] == KEY_TAG && key_value.count() > 1) {
             key_value[1] = line.right(line.length() - line.indexOf(QRegExp("\\s"))); // Get whole string after key
-            if (copyCertificates) {
-                const QString absoluteFilePath = tryToCopyToCertificatesDirectory(connectionName, unQuote(key_value[1], fileName));
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_KEY), absoluteFilePath);
-            } else {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_KEY), unQuote(key_value[1], fileName));
-            }
+            dataMap.insert(QLatin1String(NM_OPENVPN_KEY_KEY), unQuote(key_value[1], fileName));
             continue;
         }
         if (key_value[0] == SECRET_TAG && key_value.count() > 1) {
             key_value[1] = line.right(line.length() - line.indexOf(QRegExp("\\s"))); // Get whole string after key
-            if (copyCertificates) {
-                const QString absoluteFilePath = tryToCopyToCertificatesDirectory(connectionName, unQuote(key_value[1], fileName));
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_STATIC_KEY), absoluteFilePath);
-            } else {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_STATIC_KEY), unQuote(key_value[1], fileName));
-            }
+            dataMap.insert(QLatin1String(NM_OPENVPN_KEY_STATIC_KEY), unQuote(key_value[1], fileName));
             if (key_value.count() > 2) {
                 key_value[2] = key_value[1];
                 if (!key_value[2].isEmpty() && (key_value[2].toLong() == 0 ||key_value[2].toLong() == 1))
@@ -444,12 +395,7 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
         }
         if (key_value[0] == TLS_AUTH_TAG && key_value.count() >1) {
             key_value[1] = line.right(line.length() - line.indexOf(QRegExp("\\s"))); // Get whole string after key
-            if (copyCertificates) {
-                const QString absoluteFilePath = tryToCopyToCertificatesDirectory(connectionName, unQuote(key_value[1], fileName));
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_TA), absoluteFilePath);
-            } else {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_TA), unQuote(key_value[1], fileName));
-            }
+            dataMap.insert(QLatin1String(NM_OPENVPN_KEY_TA), unQuote(key_value[1], fileName));
             if (key_value.count() > 2) {
                 key_value[2] = key_value[1];
                 if (!key_value[2].isEmpty() && (key_value[2].toLong() == 0 ||key_value[2].toLong() == 1))
@@ -497,59 +443,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
             }
             continue;
         }
-        if (key_value[0] == KEY_DIRECTION_TAG) {
-            if (key_value.count() == 2) {
-                key_direction = key_value[1].toInt();
-            }
-
-            if (key_direction != 0 && key_direction != 1) {
-                KMessageBox::information(0, i18n("Invalid argument in option: %1", line));
-                key_direction = -1;
-            }
-            continue;
-        }
-
-        if (key_value[0] == BEGIN_KEY_CA_TAG) {
-            const QString caAbsolutePath = saveFile(in, QLatin1String(END_KEY_CA_TAG), connectionName, "ca.crt");
-            if (!caAbsolutePath.isEmpty()) {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_CA), caAbsolutePath);
-            }
-            continue;
-        } else if (key_value[0] == BEGIN_KEY_CERT_TAG) {
-            const QString certAbsolutePath = saveFile(in, QLatin1String(END_KEY_CERT_TAG), connectionName, "cert.crt");
-            if (!certAbsolutePath.isEmpty()) {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_CERT), certAbsolutePath);
-            }
-            continue;
-        } else if (key_value[0] == BEGIN_KEY_KEY_TAG) {
-            const QString keyAbsolutePath = saveFile(in, QLatin1String(END_KEY_KEY_TAG), connectionName, "private.key");
-            if (!keyAbsolutePath.isEmpty()) {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_KEY), keyAbsolutePath);
-            }
-            continue;
-        } else if (key_value[0] == BEGIN_KEY_SECRET_TAG) {
-            const QString secretAbsolutePath = saveFile(in, QLatin1String(END_KEY_SECRET_TAG), connectionName, "secret.key");
-            if (!secretAbsolutePath.isEmpty()) {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_KEY), secretAbsolutePath);
-                have_sk = true;
-
-                if (key_direction > -1) {
-                    dataMap.insert(QLatin1String(NM_OPENVPN_KEY_STATIC_KEY_DIRECTION), QString().setNum(key_direction));
-                }
-            }
-            continue;
-        } else if (key_value[0] == BEGIN_TLS_AUTH_TAG) {
-            const QString tlsAuthAbsolutePath = saveFile(in, QLatin1String(END_TLS_AUTH_TAG), connectionName, "tls_auth.key");
-            if (!tlsAuthAbsolutePath.isEmpty()) {
-                dataMap.insert(QLatin1String(NM_OPENVPN_KEY_TA), tlsAuthAbsolutePath);
-
-                if (key_direction > -1) {
-                    dataMap.insert(QLatin1String(NM_OPENVPN_KEY_TA_DIR), QString().setNum(key_direction));
-                }
-            }
-            continue;
-        }
-
         // Import X-NM-Routes if present
         if (key_value[0] == "X-NM-Routes") {
             ipv4Data.insert("X-NM-Routes", key_value[1]);
@@ -607,7 +500,7 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
     setting.setSecrets(secretData);
 
     QVariantMap conn;
-    conn.insert("id", connectionName);
+    conn.insert("id", QFileInfo(fileName).completeBaseName());
     conn.insert("type", "vpn");
     result.insert("connection", conn);
 
@@ -621,49 +514,6 @@ NMVariantMapMap OpenVpnUiPlugin::importConnectionSettings(const QString &fileNam
     return result;
 }
 
-QString OpenVpnUiPlugin::saveFile(QTextStream &in, const QString &endTag, const QString &connectionName, const QString &fileName)
-{
-    const QString certificatesDirectory = KStandardDirs::locateLocal("data", "networkmanagement/certificates/" + connectionName);
-    const QString absoluteFilePath = certificatesDirectory + '/' + fileName;
-    QFile outFile(absoluteFilePath);
-
-    QDir().mkpath(certificatesDirectory);
-    if (!outFile.open(QFile::WriteOnly | QFile::Text)) {
-        KMessageBox::information(0, i18n("Error saving file %1: %2", absoluteFilePath, outFile.errorString()));
-        return QString();
-    }
-
-    QTextStream out(&outFile);
-    while (!in.atEnd()) {
-        const QString line = in.readLine();
-
-        if (line.indexOf(endTag) >= 0) {
-            break;
-        }
-
-        out << line << "\n";
-    }
-
-    outFile.close();
-    return absoluteFilePath;
-}
-
-QString OpenVpnUiPlugin::tryToCopyToCertificatesDirectory(const QString &connectionName, const QString &sourceFilePath)
-{
-    const QString certificatesDirectory = KStandardDirs::locateLocal("data", "networkmanagement/certificates/");
-    const QString absoluteFilePath = certificatesDirectory + connectionName + '_' + QFileInfo(sourceFilePath).fileName();
-
-    QFile sourceFile(sourceFilePath);
-
-    QDir().mkpath(certificatesDirectory);
-    if (!sourceFile.copy(absoluteFilePath)) {
-        KMessageBox::information(0, i18n("Error copying certificate to %1: %2", absoluteFilePath, sourceFile.errorString()));
-        return sourceFilePath;
-    }
-
-    return absoluteFilePath;
-}
-
 bool OpenVpnUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionSettings::Ptr &connection, const QString &fileName)
 {
     QFile expFile(fileName);
@@ -805,9 +655,8 @@ bool OpenVpnUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionS
             }
         }
     }
-    // Export never default setting.
-    NetworkManager::Ipv4Setting::Ptr ipv4Setting = connection->setting(NetworkManager::Setting::Ipv4).dynamicCast<NetworkManager::Ipv4Setting>();
     // Export X-NM-Routes
+    NetworkManager::Ipv4Setting::Ptr ipv4Setting = connection->setting(NetworkManager::Setting::Ipv4).dynamicCast<NetworkManager::Ipv4Setting>();
     if (!ipv4Setting->routes().isEmpty()) {
         QString routes;
         foreach(const NetworkManager::IpRoute &route, ipv4Setting->routes()) {
@@ -829,3 +678,5 @@ bool OpenVpnUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionS
     expFile.close();
     return true;
 }
+
+#include "openvpn.moc"
