@@ -23,9 +23,11 @@
 #include "nm-openvpn-service.h"
 #include "settingwidget.h"
 
+#include <QStandardPaths>
+#include <QUrl>
+
 #include <KLocalizedString>
 #include <KProcess>
-#include <KStandardDirs>
 #include <KAcceleratorManager>
 
 class OpenVpnAdvancedWidget::Private {
@@ -68,7 +70,7 @@ OpenVpnAdvancedWidget::OpenVpnAdvancedWidget(const NetworkManager::VpnSetting::P
     connect(m_ui->cmbProxyType, SIGNAL(currentIndexChanged(int)), this, SLOT(proxyTypeChanged(int)));
 
     // start openVPN process and get its cipher list
-    const QString openVpnBinary = KStandardDirs::findExe("openvpn", "/sbin:/usr/sbin");
+    const QString openVpnBinary = QStandardPaths::findExecutable("openvpn", QStringList() << "/sbin" << "/usr/sbin");
     const QStringList args(QLatin1String("--show-ciphers"));
     d->openvpnProcess = new KProcess(this);
     d->openvpnProcess->setOutputChannelMode(KProcess::OnlyStdoutChannel);
@@ -208,17 +210,8 @@ void OpenVpnAdvancedWidget::loadConfig()
     if (dataMap.contains(NM_OPENVPN_KEY_TLS_REMOTE)) {
         m_ui->subjectMatch->setText(dataMap[NM_OPENVPN_KEY_TLS_REMOTE]);
     }
-
-    if (dataMap.contains(NM_OPENVPN_KEY_REMOTE_CERT_TLS)) {
-        const QString remoteCertTls = dataMap[NM_OPENVPN_KEY_REMOTE_CERT_TLS];
-        m_ui->chkRemoteCertTls->setChecked(true);
-        m_ui->labelRemoteCertTls->setEnabled(true);
-        m_ui->cmbRemoteCertTls->setEnabled(true);
-        m_ui->cmbRemoteCertTls->setCurrentIndex(remoteCertTls == QLatin1String("server") ? 0 : 1);
-    }
-
     m_ui->useExtraTlsAuth->setChecked(!dataMap[NM_OPENVPN_KEY_TA].isEmpty());
-    m_ui->kurlTlsAuthKey->setUrl(KUrl(dataMap[NM_OPENVPN_KEY_TA]) );
+    m_ui->kurlTlsAuthKey->setUrl(QUrl::fromLocalFile(dataMap[NM_OPENVPN_KEY_TA]) );
     if (dataMap.contains(NM_OPENVPN_KEY_TA_DIR)) {
         const uint tlsAuthDirection = dataMap[NM_OPENVPN_KEY_TA_DIR].toUInt();
         m_ui->cboDirection->setCurrentIndex(tlsAuthDirection + 1);
@@ -329,13 +322,8 @@ NetworkManager::VpnSetting::Ptr OpenVpnAdvancedWidget::setting() const
     if (!m_ui->subjectMatch->text().isEmpty()) {
         data.insert(QLatin1String(NM_OPENVPN_KEY_TLS_REMOTE), m_ui->subjectMatch->text());
     }
-
-    if (m_ui->chkRemoteCertTls->isChecked()) {
-        data.insert(QLatin1String(NM_OPENVPN_KEY_REMOTE_CERT_TLS), m_ui->cmbRemoteCertTls->currentText().toLower());
-    }
-
     if (m_ui->useExtraTlsAuth->isChecked()) {
-        KUrl tlsAuthKeyUrl = m_ui->kurlTlsAuthKey->url();
+        QUrl tlsAuthKeyUrl = m_ui->kurlTlsAuthKey->url();
         if (!tlsAuthKeyUrl.isEmpty()) {
             data.insert(QLatin1String(NM_OPENVPN_KEY_TA), tlsAuthKeyUrl.path());
         }
