@@ -23,13 +23,14 @@
 
 #include "vpnc.h"
 
+#include <QStandardPaths>
+#include <QFile>
+
 #include <KPluginFactory>
 #include <KSharedConfig>
-#include <KStandardDirs>
 #include <KMessageBox>
-#include <KLocale>
-#include <KDebug>
-#include <KUrl>
+#include <KLocalizedString>
+#include <QDebug>
 #include "nm-vpnc-service.h"
 
 #include <NetworkManagerQt/Connection>
@@ -80,7 +81,7 @@ void VpncUiPluginPrivate::ciscoDecryptFinished(int exitCode, QProcess::ExitStatu
 void VpncUiPluginPrivate::ciscoDecryptError(QProcess::ProcessError pError)
 {
     if (!pError) {
-        kDebug() << "Error in executing cisco-decrypt";
+        qDebug() << "Error in executing cisco-decrypt";
         KMessageBox::error(0, i18n("Error decrypting the obfuscated password"), i18n("Error"), KMessageBox::Notify);
     }
     decryptedPasswd.clear();
@@ -89,8 +90,7 @@ void VpncUiPluginPrivate::ciscoDecryptError(QProcess::ProcessError pError)
 
 #define NM_VPNC_LOCAL_PORT_DEFAULT 500
 
-K_PLUGIN_FACTORY(VpncUiPluginFactory, registerPlugin<VpncUiPlugin>();)
-K_EXPORT_PLUGIN(VpncUiPluginFactory("plasmanetworkmanagement_vpncui"))
+K_PLUGIN_FACTORY_WITH_JSON(VpncUiPluginFactory, "plasmanetworkmanagement_vpncui.json", registerPlugin<VpncUiPlugin>();)
 
 VpncUiPlugin::VpncUiPlugin(QObject * parent, const QVariantList &) : VpnUiPlugin(parent)
 {
@@ -124,7 +124,7 @@ QString VpncUiPlugin::supportedFileExtensions() const
 
 NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
 {
-    kDebug() << "Importing Cisco VPN connection from " << fileName;
+    qDebug() << "Importing Cisco VPN connection from " << fileName;
 
     VpncUiPluginPrivate * decrPlugin = 0;
     NMVariantMapMap result;
@@ -146,7 +146,7 @@ NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
     KConfigGroup cg(config, "main");   // Keys&Values are stored under [main]
     if (cg.exists()) {
         // Setup cisco-decrypt binary to decrypt the passwords
-        const QString ciscoDecryptBinary = KStandardDirs::findExe("cisco-decrypt", QString::fromLocal8Bit(qgetenv("PATH")) + ":/usr/lib/vpnc");
+        const QString ciscoDecryptBinary = QStandardPaths::findExecutable("cisco-decrypt", QStringList() << QFile::decodeName(qgetenv("PATH")) << "/usr/lib/vpnc");
         if (ciscoDecryptBinary.isEmpty()) {
             mErrorMessage = i18n("Needed executable cisco-decrypt could not be found.");
             return result;
@@ -280,12 +280,7 @@ NMVariantMapMap VpncUiPlugin::importConnectionSettings(const QString &fileName)
         setting.setSecrets(secretData);
 
         QVariantMap conn;
-        if (decrPlugin->readStringKeyValue(cg,"Description").isEmpty()) {
-            KUrl name = fileName;
-            conn.insert("id", name.fileName().remove(QLatin1String(".pcf"), Qt::CaseInsensitive));
-        } else {
-            conn.insert("id", decrPlugin->readStringKeyValue(cg,"Description"));
-        }
+        conn.insert("id", decrPlugin->readStringKeyValue(cg,"Description"));
         conn.insert("type", "vpn");
         result.insert("connection", conn);
 
@@ -395,3 +390,5 @@ bool VpncUiPlugin::exportConnectionSettings(const NetworkManager::ConnectionSett
     mError = VpncUiPlugin::NoError;
     return true;
 }
+
+#include "vpnc.moc"
