@@ -23,6 +23,8 @@
 #include "ui_vpnc.h"
 #include "nm-vpnc-service.h"
 
+#include <QUrl>
+
 #include <QDBusMetaType>
 #include <QDebug>
 
@@ -44,15 +46,6 @@ VpncWidget::VpncWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget*
 
     KAcceleratorManager::manage(this);
 
-    m_advancedWidget = new VpncAdvancedWidget(m_setting, this);
-    NMStringMap advData = m_advancedWidget->setting();
-    if (!advData.isEmpty()) {
-        if (m_tmpSetting.isNull()) {
-            m_tmpSetting = NetworkManager::VpnSetting::Ptr(new NetworkManager::VpnSetting);
-        }
-        m_tmpSetting->setData(advData);
-    }
-
     if (m_setting)
         loadConfig(setting);
 }
@@ -60,7 +53,6 @@ VpncWidget::VpncWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget*
 VpncWidget::~VpncWidget()
 {
     m_tmpSetting.clear();
-    m_advancedWidget->deleteLater();
     delete m_ui;
 }
 
@@ -111,7 +103,7 @@ void VpncWidget::loadConfig(const NetworkManager::Setting::Ptr &setting)
 
     if (data.value(NM_VPNC_KEY_AUTHMODE) == QLatin1String("hybrid")) {
         m_ui->useHybridAuth->setChecked(true);
-        m_ui->caFile->setUrl(KUrl::fromPath(data.value(NM_VPNC_KEY_CA_FILE)));
+        m_ui->caFile->setUrl(QUrl(data.value(NM_VPNC_KEY_CA_FILE)));
     }
 }
 
@@ -120,11 +112,10 @@ QVariantMap VpncWidget::setting(bool agentOwned) const
     NetworkManager::VpnSetting setting;
     setting.setServiceType(QLatin1String(NM_DBUS_SERVICE_VPNC));
     NMStringMap data;
-    NMStringMap secrets;
-
     if (!m_tmpSetting.isNull()) {
         data = m_tmpSetting->data();
     }
+    NMStringMap secrets;
 
     if (!m_ui->gateway->text().isEmpty())
         data.insert(NM_VPNC_KEY_GATEWAY, m_ui->gateway->text());
@@ -195,13 +186,25 @@ void VpncWidget::showPasswords(bool show)
 
 void VpncWidget::showAdvanced()
 {
-    m_advancedWidget->loadConfig(m_tmpSetting);
-    if (m_advancedWidget->exec() == QDialog::Accepted) {
-        NMStringMap advData = m_advancedWidget->setting();
+    QPointer<VpncAdvancedWidget> adv;
+    if (m_tmpSetting.isNull()) {
+        adv = new VpncAdvancedWidget(m_setting, this);
+    } else {
+        adv = new VpncAdvancedWidget(m_tmpSetting, this);
+    }
+    if (adv->exec() == QDialog::Accepted) {
+        NMStringMap advData = adv->setting();
         if (!advData.isEmpty()) {
+            if (m_tmpSetting.isNull()) {
+                m_tmpSetting = NetworkManager::VpnSetting::Ptr(new NetworkManager::VpnSetting);
+            }
             m_tmpSetting->setData(advData);
         }
     }
+
+    if (adv) {
+        adv->deleteLater();
+    }
 }
 
 bool VpncWidget::isValid() const
